\name{F13}
\alias{F13}
\encoding{latin1}
\title{MULTIPLE SCATTER PLOT FOR VARIABLE X QUANTITATIVE}
\description{It performs a multiple scatter plot with or without text labels and a regression model for each category.}
\usage{
F13(data, varY,  varX, group, textlabel=NULL, label=NULL, reg=FALSE,
model="Linear", outliers=FALSE, quant1=0.05, quant2 = 0.95,  ResetPAR=TRUE,
PAR=NULL, XLAB=NULL, YLAB=NULL, COLOR=NULL, COLORR=NULL, PCH=NULL, CEX=1,
lty=NULL, lwd=2.5, PLOT=NULL, LEGEND=NULL, AXIS=NULL, MTEXT=NULL,
TEXT=NULL, dec=",", file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Quantitative independent variable.}
  \item{group}{Variable with the categories to be grouped.}
  \item{textlabel}{Variable with the text labels.}
  \item{label}{It allows to specify the characteristics of the text labels with the function \link[graphics]{text}.}
  \item{reg}{If TRUE a regression model is performed.}
  \item{model}{One regression model can be selected: "Linear" , "Log", "S-curve", "Power", "Exp", "Quadratic", "Cubic", "Inverse".  It is not considered the model in those cases in which there is the logarithm that apply to any of the variables, if any value of the variable, which applies the logarithm, is zero or negative. The inverse model is not calculated if any value of the independent variable is zero.}
\item{outliers}{If it is TRUE, the outliers are removed using the selected regression model.}
  \item{quant1}{Quantile of the lower end to the elimination of outliers.}
  \item{quant2}{Quantile of the upper end to the elimination of outliers.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{COLOR}{Color of the symbols. It must be as many as different categories of the variable \emph{group}.}
  \item{COLORR}{Color of the line of the regression model. It must be as many as different categories of the variable \emph{group}.}
  \item{PCH}{Graphic symbol (see the description of the same argument in the function \link{F1}). It must be as many as different categories of the variable \emph{group}.}
  \item{CEX}{Size of the symbols.}
  \item{lty}{Type of the regression line (see the description of the same argument in the function \link{F1}).}
  \item{lwd}{Line width of the regression line relative to the default (default=1), so 2 is twice as wide.}
  \item{PLOT}{It allows to specify the characteristics of the function \link[graphics]{plot.default}.}
  \item{LEGEND}{It allows to modify the legend of the graph.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
  \item{dec}{It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{file}{TXT FILE. If the argument \emph{reg=TRUE} a TXT file is saved with the information of the regression.}
}
\value{A multiple scatter plot with or without text labels and regression models for different categories is obtained.}  
\details{

\strong{FUNCTIONS}

The plot is performed with the function \link[graphics]{plot.default} of base graphics package and the linear regression with the function \link[stats]{lm} of base stats package. The function \link[nortest]{lillie.test} of the package nortest (Gross, 2013) is used to perform the test of Normality Kolmogorov-Smirnov with Lilliefors'correction, the function \link[lmtest]{dwtest} of the package lmtest (Hothorn et al., 2013) to analyze the autocorrelation with the test and the Durbin-Watson statistic function \link[lmtest]{bptest} of the package lmtest (Hothorn et al., 2013) to perform the Breusch-Pagan test of homoscedasticity.

\strong{EXAMPLES}

\strong{Example 1} The data are scores of a Principal Component Analysis (PCA) performed to physicochemical parameters from lakes in Colombia. In this example, text labels are assigned to the points with the argument \emph{textlabel="Lake"}, and the different regions are identified with the argument \emph{group="Region"}.
\tabular{c}{
\figure{F35}{options: width=4.5in}
}
\strong{Example 2} For the examples, morphometric data of several fish species of Characiforms, as the distance from the origin of the dorsal fin to the origin of the anal fin (M13), the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010). It is shown the relationship between M11 and M13 for each genera.
\tabular{c}{
\figure{F36}{options: width=3.8in}
}
\strong{Example 3} A linear regression line is added to the example 2 with the argument \emph{reg=TRUE}.
\tabular{c}{
\figure{F37}{options: width=3.8in}
}
In the TXT file that generates the function, the regression model of each genera is shown. For the explanation of the regression models, normality, autocorrelation and homoscedasticity see the \emph{details} section of the function \link{F1}.
}
\references{
Durbin, J. & Watson G.S. (1951) Testing for serial correlation in least squares regression. \emph{Biometrika}, \strong{38}, 159-171.

Gross, J. (2013) Tests for Normality. R package version 1.0-2. Available at: \url{https://CRAN.R-project.org/package=nortest}.

Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.

Hothorn, T. et al., (2013) Testing Linear Regression Models. R package version 0.9-33. Available at: \url{https://CRAN.R-project.org/package=lmtest}.
}
\examples{
\dontrun{

#Example 1

data(Z6)

F13(data=Z6 , varY="Dimension2", varX="Dimension1", group="Region",
textlabel="Lake", XLAB="Dimension 1", YLAB="Dimension 2", PLOT=c("xlim=c(-1,1)",
"xlab=xlab", "ylab=ylab", "col=COLOR", "pch=PCH"))

#Example 2

data(Z1)

F13(data=Z1, varY="M13", varX="M11", group="Genus")

#Example 3

F13(data=Z1, varY="M13", varX="M11", group="Genus", reg=TRUE)
}
}
\keyword{F13}
