\name{F15}
\alias{F15}
\encoding{latin1}
\title{MULTIPLE DOT OR MEAN WITH ERROR BARS SCATTER PLOTS FOR VARIABLE X QUALITATIVE}
\description{It performs a multiple dot or mean with error bars scatter plots for variable X qualitative.}
\usage{
F15(data, varY, FactorX, group, method="mean", dev="sd", ResetPAR=TRUE,
PAR=NULL, order=NULL, OrderCat=NULL, LabelCat=NULL, XLAB=NULL, YLAB=NULL,
XLIM=NULL, YLIM=NULL, COLOR=NULL, COLORI="black", PCH=NULL, CEX=1, LEGEND=NULL,
AXIS=NULL,MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{FactorX}{Qualitative independent variable.}
  \item{group}{Variable with the categories to be grouped.}
  \item{method}{If it is not NULL, the average of each category of the independent variable \emph{FactorX} is estimated with the "mean" or the "median".}
  \item{dev}{If the argument \emph{method} is not NULL, the error bars may be estimated using the standard deviation ("sd") or the standard error ("se").}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{order}{If it is NULL the categories are ordered as found in the variable \emph{FactorX}, if it is "increasing" are ordered from lesser to greater median or mean according to the method selected in the argument \emph{method}, if it is "decreasing" are ordered from greater to lesser median or mean, if it is "alhaAZ" are ordered from A to Z and if it is "alphaZA" from Z to A.} 
  \item{OrderCat}{It allows to specify a vector with the order in which the categories are shown. If this argument is specified, the argument \emph{order} is not taken into account.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{XLIM}{Vector with the limits of the X axis.}
  \item{YLIM}{Vector with the limits of the Y axis.}
  \item{COLOR}{Color of the symbols. It must be as many as different categories of the variable \emph{group}.}
  \item{COLORI}{Color of the error bars.}
  \item{PCH}{Graphic symbol (see the description of the same argument in the function \link{F1}). It must be as many as different categories of the variable \emph{group}.}
  \item{CEX}{Size of the symbols.}
  \item{LEGEND}{It allows to modify the legend of the graph.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
}
\value{A multiple dot or mean scatter plots are obtained.}  
\details{
\strong{FUNCTIONS}

The plot is performed with the functions \link[graphics]{boxplot}, \link[graphics]{points} and \link[graphics]{arrows} of base graphics package. For further details see Guisande & Vammonde (2012).

\strong{EXAMPLES}

For the examples, morphometric data of three families of freshwater fishes, as the distance from the origin of the dorsal fin to the origin of the anal fin (M13), the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010).

\strong{Example 1} A dot plot is depicted with the argument \emph{method=NULL} of the variable M11 for all genera of fishes grouped by families. The different genera are ordered from greater to lesser with the argument \emph{order="increasing"}. The legend of the axis X is removed with the argument \emph{XLAB=""}. In the argument \emph{PAR} the argument \emph{las=2} means that the legend of the axis are perpendicular to the axis and the size of the axis labels are modified with the argument \emph{cex.axis=0.62}.
\tabular{c}{
\figure{F41}{options: width=3.4in}
}
\strong{Example 2} The mean and the standard deviation of the variable M11 is obtained for each genus.
\tabular{c}{
\figure{F42}{options: width=3.8in}
}
}
\references{
Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.
}
\examples{
\dontrun{

#Example 1

data(Z8)

F15(data=Z8, varY="M11", FactorX="Genus", group="Order", method=NULL,
PAR = c("cex.lab = 1.5" , "font.lab = 2" , "las = 2" , "mar = c(5,5,3,2)",
"cex.axis=0.62"), order="decreasing", XLAB="", LEGEND = c("x = 'topright'",
"legend = dati" , "col = COLOR" , "pch = PCH" , "bty = 'n'"))

#Example 2

F15(data=Z8, varY="M11", FactorX="Genus", group="Family", PAR = c("cex.lab = 1.5",
"font.lab = 2", "las = 2", "mar = c(5,5,3,2)", "cex.axis=0.62"), XLAB="",
order="increasing")
}
}
\keyword{F15}
