\name{F19}
\alias{F19}
\encoding{latin1}
\title{HISTOGRAM WITH ONE OR SEVERAL VARIABLES}
\description{It performs a histogram with one or several variables.}
\usage{
F19(data, var, HIST=NULL, HISTh=NULL, breaks=20, varbreak=FALSE, horiz=FALSE,
line=FALSE, lty=1, lwd=2.5, ResetPAR=TRUE,  PAR=NULL,  XLAB=NULL, YLAB=NULL,
XLIM=NULL, YLIM=NULL, COLOR=NULL, COLORb="transparent", LEGEND=NULL,
AXIS=NULL, MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{var}{Variables.}
  \item{HIST}{It allows to specify the characteristics of the vertical histogram with the function \link[graphics]{hist}.}
  \item{HISTh}{It allows to specify the characteristics of the horizontal histogram with the function \link[graphics]{barplot}.}
  \item{breaks}{Number of intervals.}
  \item{varbreak}{If it is TRUE the intervals are defined by the variables.}
  \item{horiz}{If it is FALSE, the bars are drawn vertically with the first bar to the left. If it is TRUE, the bars are drawn horizontally with the first at the bottom.}
  \item{line}{If it is TRUE a density line is depicted only if the arguments \emph{varbreak=FALSE} and \emph{horiz=FALSE}.}
  \item{lty}{Type of line of the density curve for each variable. If it is a vector, it must be as many as different variables. See the description of the same argument in the function \link{F1}.}
  \item{lwd}{Line width relative to the default (default=1), so 2 is twice as wide.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that modifies many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{XLIM}{Vector with the limits of the X axis.}
  \item{YLIM}{Vector with the limits of the Y axis.}
  \item{COLOR}{Color of the borders. It must be as many as different variables.}
  \item{COLORb}{Color of the bars. It must be as many as different variables.}
  \item{LEGEND}{It modifies the legend of the graph. If it is FALSE the legend is not shown.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
}
\value{A histogram for one or several variables is obtained.}  
\details{
\strong{FUNCTIONS}

The histograms are performed with the functions \link[graphics]{hist} and \link[graphics]{barplot} of base graphics package.

\strong{EXAMPLES}

For the examples, morphometric data of three families of freshwater fishes are used. For details see Guisande et al. (2010).

\strong{Example 1} A histogram with the intervals defined by the variables with the argument \emph{varbreak=TRUE}.
\tabular{c}{
\figure{F48}{options: width=3.6in}
}
\strong{Example 2} A histogram with the intervals defined by the user. The number of intervals may be modified with the argument \emph{breaks}.
\tabular{c}{
\figure{F49}{options: width=4in}
}
\strong{Example 3} A density line is added with the argument \emph{line=TRUE}.
\tabular{c}{
\figure{F50}{options: width=3.8in}
}
\strong{Example 4} A histogram with one variable. The legend is not shown using the argument \emph{LEGEND=FALSE} and the bars are horizontal with the argument \emph{horiz=TRUE}.
\tabular{c}{
\figure{F51}{options: width=3.8in}
}
}
\references{
Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.
}
\examples{
\dontrun{

data(Z8)

#Example 1

F19(data=Z8, var=c("M15","M16"), varbreak=TRUE)

#Example 2

F19(data=Z8, var=c("M15","M16"))

#Example 3

F19(data=Z8, var=c("M15","M16"), line=TRUE)

#Example 4

F19(data=Z8, var=c("M15"), horiz=TRUE, XLAB="M15", LEGEND=FALSE)
}
}
\keyword{F19}
