\name{F25}
\alias{F25}
\encoding{latin1}
\title{BOX AND WHISKER PLOTS}
\description{It performs box and whisker plots.}
\usage{
F25(data, varY, varX, order=NULL, jitter=FALSE, ResetPAR=TRUE, PAR=NULL,
OrderCat=NULL, LabelCat=NULL, COLOR=NULL, BOXPLOT=NULL, LEGEND=NULL,
AXIS=NULL, MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Variable with the categories.}
  \item{order}{If it is NULL the categories are ordered as found in the variable \emph{varX}, if it is "increasing" are ordered from lesser to greater median, if it is "decreasing" are ordered from greater to lesser median, if it is "alhaAZ" are ordered from A to Z and if it is "alphaZA" from Z to A.}
  \item{jitter}{If it is TRUE points are added with the function \link[base]{jitter} of the base package.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{OrderCat}{It allows to specify a vector with the order in which the categories are shown. If this argument is specified, the argument \emph{order} is not taken into account.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories.}
  \item{COLOR}{Vector with the color of the categories or just one color for all categories.}
  \item{BOXPLOT}{It allows to specify the characteristics of the function \link[graphics]{boxplot}.}
  \item{LEGEND}{It allows to include a legend to the graph.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}

}
\value{A box or whisker plot is obtained.}  
\details{

\strong{FUNCTIONS}

The plot is performed with the functions \link[graphics]{boxplot} of the graphics package and \link[base]{jitter} of the base package.

\strong{EXAMPLES}

For the examples, morphometric data of several fish species of Characiforms, as the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010). It is shown the length of the dorsal fin base (M12) for all genera. 

\strong{Example 1.} Genera are ordered as found in the varX.
\tabular{c}{
\figure{F1}{options: width=3.6in}
}
\strong{Example 2.} Genera are ordered from lesser to greater median with the argument (\emph{order="increasing"}) and outliers are removed (in the argument \emph{BOXPLOT} select \emph{outline=FALSE}).
\tabular{c}{
\figure{F2}{options: width=3.6in}
}
\strong{Example 3.} Genera are plotted in alphabetical order from A to Z with the argument (\emph{order="alphaAZ"}) and a notch is included (in the argument \emph{BOXPLOT} select \emph{notch=TRUE}). If the notches of two plots do not overlap this is an evidence that the two medians differ (Chambers et al, 1983, p. 62). See \link[grDevices]{boxplot.stats} for the calculations used.
\tabular{c}{
\figure{F3}{options: width=3.7in}
}
\strong{Example 4.} Genera are ordered from greater to lesser median with the argument (\emph{order="decreasing"}) and the boxes are drawn with widths proportional to the square-roots of the number of observations in the groups (in the argument \emph{BOXPLOT} select \emph{varwidth=TRUE}).
\tabular{c}{
\figure{F4}{options: width=3.7in}
}
\strong{Example 5.} As in the example 1 but with the argument \emph{jitter=TRUE}
\tabular{c}{
\figure{F168}{options: width=3.7in}
}
}
\references{
Chambers, J. M., Cleveland, W. S., Kleiner, B. and Tukey, P. A. (1983) \emph{Graphical Methods for Data Analysis}. Wadsworth & Brooks/Cole.

Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.
}
\examples{
\dontrun{

data(Z1)

#Example 1.

F25(data=Z1, varY="M12", varX="Genus")

#Example 2.

F25(data=Z1, varY="M12", varX="Genus", order="increasing",
BOXPLOT = c("outline=FALSE", "col=color", "xlab=varX", "ylab=varY"))

#Example 3.

F25(data=Z1, varY="M12", varX="Genus", order="alphaAZ",
BOXPLOT = c("notch=TRUE", "col=color", "xlab=varX", "ylab=varY"))

#Example 4.

F25(data=Z1, varY="M12",varX="Genus", order="deacreasing",
BOXPLOT = c("varwidth=TRUE", "col=color", "xlab=varX", "ylab=varY"))

#Example 5.

F25(data=Z1, varY="M12", varX="Genus", jitter=TRUE)
}
}
\keyword{F25}
