\name{F26}
\alias{F26}
\encoding{latin1}
\title{BEANPLOTS AND STRIPCHARTS}
\description{It performs beanplots and stripcharts.}
\usage{
F26(data, varY, varX, order=NULL, side="no", beanlines="median", what=c(1,1,1,1),
border="black", ResetPAR=TRUE, PAR=NULL, OrderCat=NULL, LabelCat=NULL,
COLOR=NULL, BEANPLOT=NULL, LEGEND=NULL, AXIS=NULL, MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Variable with the categories.}
  \item{order}{If it is NULL the categories are ordered as found in the variable \emph{varX}, if it is "increasing" are ordered from lesser to greater median or mean according to the method selected in the argument \emph{beanlines}, if it is "decreasing" are ordered from greater to lesser median or mean, if it is "alhaAZ" are ordered from A to Z and if it is "alphaZA" from Z to A. If the method selected in \emph{beanlines="quantiles"}, it is used the median for both "increasing" and "decreasing".}
  \item{side}{The side on which the beans are plot. Default is "no", for symmetric beans. The options "first", "second" and "both" are also supported.}
  \item{beanlines}{The method used for determining the average bean lines. Default is value "median", and other options are "mean" and "quantiles".}
  \item{what}{A vector of four booleans describing what to plot. In the following order, these booleans stand for the total average line, the beans, the bean average, and the beanlines. For example, \emph{what=c(0,0,0,1)} produces a \link[graphics]{stripchart}.}
  \item{border}{Color of the border around the bean.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR}, allowing to modify different aspects of the graph.}
  \item{OrderCat}{It allows to specify a vector with the order in which the categories are shown. If this argument is specified, the argument \emph{order} is not taken into account.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories.}
  \item{COLOR}{Vector with the color of the categories or just one color for all categories.}
  \item{BEANPLOT}{It allows to specify the characteristics of the function \link[beanplot]{beanplot}.}
  \item{LEGEND}{It allows to include a legend to the graph.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}

}
\value{A beanplot and stripchart plot is obtained.}  
\details{

\strong{FUNCTIONS}

The graph is performed with the function \link[beanplot]{beanplot} of the beanplot package (Kampstra, 2008; Kampstra, 2015). For further details see the help of the function \link[beanplot]{beanplot} and/or Guisande & Vammonde (2012).

\strong{EXAMPLES}

For the examples, morphometric data of several fish species of Characiforms, as the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010). It is shown the length of the dorsal fin base (M12) for all genera. 

\strong{Example 1.} Genera are ordered as found in the varX.
\tabular{c}{
\figure{F5}{options: width=3.5in}
}
\strong{Example 2.} One color for all categories just modifying the argument \emph{COLOR="green"}.
\tabular{c}{
\figure{F6}{options: width=3.5in}
}
\strong{Example 3.} Genera are ordered from lesser to greater median with the argument (\emph{order="increasing"}).
\tabular{c}{
\figure{F7}{options: width=3.5in}
}
\strong{Example 4.} Genera are plotted in alphabetical order from A to Z with the argument (\emph{order="alphaAZ"}).
\tabular{c}{
\figure{F8}{options: width=4in}
}
\strong{Example 5.} Genera are depicted in pairs with the argument (\emph{side="both"}).
\tabular{c}{
\figure{F9}{options: width=4in}
}
\strong{Example 6.} Naked beanplots are depicted modifying the argument (\emph{what=c(0,1,1,0)} and \emph{border="transparent"}).
\tabular{c}{
\figure{F10}{options: width=4in}
}
\strong{Example 7.} A stripchart is depicted modifying the argument (\emph{what=c(0,0,1,1)}).
\tabular{c}{
\figure{F11}{options: width=5in}
}
\strong{Example 8.} With the argument \emph{BEANPLOT} is possible to access the function \link[beanplot]{beanplot}, where the argument \emph{col} is a list with four values: the colors of the area of the beans (without the border, use border for that color), the lines inside the bean, the lines outside the bean and the average line per bean. Therefore, it is possible to modify the color of any of these items, just changing the colors. Moreover, the size of the lines inside the beans, which shows where there are more data within the distribution, it may be modified to a smaller value with the argument \emph{ll=0.05}, which means that the line width is thinner when there is overlap of data.
\tabular{c}{
\figure{F12}{options: width=5in}
}
}
\references{
Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Kampstra, P (2008). Beanplot: A Boxplot Alternative for Visual Comparison of Distributions. \emph{Journal of Statistical Software, Code Snippets}, 28: 1-9.

Kampstra, P (2015) Visualization via Beanplots (like Boxplot/Stripchart/Violin Plot). R package version 1.2. Available at: \url{https://CRAN.R-project.org/package=beanplot}.
}
\examples{
\dontrun{

data(Z1)

#Example 1.

F26(data=Z1, varY="M12", varX="Genus")

#Example 2.

F26(data=Z1, varY="M12", varX="Genus", COLOR="green")

#Example 3.

F26(data=Z1, varY="M12", varX="Genus", order="increasing")

#Example 4.

F26(data=Z1, varY="M12", varX="Genus", order="alphaAZ")

#Example 5.

F26(data=Z1, varY="M12", varX="Genus", side="both")

#Example 6.

F26(data=Z1, varY="M12", varX="Genus", what=c(0,1,1,0), border="transparent")

#Example 7.

F26(data=Z1, varY="M12", varX="Genus", what=c(0,0,1,1))

#Example 8.

F26(data=Z1, varY="M12", varX="Genus", order="alphaAZ",
BEANPLOT = c("col = list(c('red','green','black','black'))" , "ll=0.05",
"ylab = varY" , "xlab = varX", "beanlines=beanlines"))
}
}
\keyword{F26}
