\name{F27}
\alias{F27}
\encoding{latin1}
\title{GOOGLE GEO MAPS}
\description{A geo map is a map of a country, continent, or region map, with colors and values assigned to specific regions.}
\usage{
F27(data, locationvar, numvar, hovervar, region="world",
showLegend=TRUE, width=1000, height=500, dataMode="regions",
colors=c("#E0FFD400", "#A5EF6300", "#50AA0000", "#26711400"), chartid)
}
\arguments{
  \item{data}{Data file.}
  \item{locationvar}{Variable with the geo locations to be analyzed. The locations can be provide in two formats:

Format 1 "latitude:longitude". See the example 1 below.

Format 2 (see example 2 below). Address, country name, region name locations, or US metropolitan area codes, see \url{http://code.google.com/apis/adwords/docs/developer/
adwords_api_us_metros.html}. This format works with the dataMode option set to either "markers" or "regions". The following formats are accepted: A specific address (for example, "1600 Pennsylvania Ave"). A country name as a string (for example, "England"), or an uppercase ISO-3166 code or its English text equivalent (for example, "GB" or "United Kingdom"). An uppercase ISO-3166-2 region code name or its English text equivalent (for example, "US-NJ" or "New Jersey").}
  \item{numvar}{Variable with the numeric value displayed when the user hovers over this region.}
  \item{hovervar}{Variable with the additional string text displayed when the user hovers over this region.}
  \item{region}{The area to display on the map (surrounding areas will be displayed as well). Can be either a country code (in uppercase ISO-3166 format), or a one of the following strings described in \url{http://developers.google.com/chart/interactive/docs/gallery/geomap#Configuration_Options}:

"world" (Whole world)

"us_metro" (United States, metro areas)

"005" (South America)

"013" (Central America)

"021" (North America)

"002" (All of Africa)

"017" (Central Africa)

"015" (Northern Africa)

"018" (Southern Africa)

"030" (Eastern Asia)

"034" (Southern Asia)

"035" (Asia/Pacific region)

"143" (Central Asia)

"145" (Middle East)

"151" (Northern Asia)

"154" (Northern Europe)

"155" (Western Europe)

"039" (Southern Europe)
}
  \item{showLegend}{If TRUE, display a legend for the map.}
  \item{width}{Width of the visualization.}
  \item{height}{Height of the visualization.}
  \item{dataMode}{How to display values on the map. Two values are supported: "regions" that colors a whole region with the appropriate color, and "markers" that displays a dot over a region, with the color and size indicating the value.}
  \item{colors}{Color gradient to assign to values in the visualization. You must have at least two values.}
  \item{chartid}{Character. If missing (default) a random chart id will be generated based on chart type and \link{tempfile}.}
}
\value{See the value section of the function \link[googleVis]{gvisGeoMap}.}  
\details{
The plot obtained is shown as a web page, so internet connection is required. This web page may be saved as complete web page and the HTML file obtained may be used, for instance, in a PowerPoint presentation with a hyperlink. For further information see \emph{details} section of the function \link[googleVis]{gvisGeoMap}.

\strong{FUNCTIONS}

The plot is performed with the function \link[googleVis]{gvisGeoMap} of the package googleVis (Gesmann & de Castillo, 2011; 2015). For further details see the help of the function \link[googleVis]{gvisGeoMap} and/or Guisande & Vammonde (2012).

\strong{EXAMPLES}

\strong{Example 1}

Magnitude and depth of several earthquakes which have happened around the world. The data were obtained from the web site \url{http://earthquake.usgs.gov/earthquakes/}.

In the example the magnitude of the earthquake is shown in a gradient and the depth in km is displayed when the user hovers over the circle.
\tabular{c}{
\figure{F18}{options: width=5in}
}
\strong{Example 2}

The data are the population size, growth rate and annual population growth of several countries obtained from the web site world gazetter.

In the example the population size of each country is shown in a gradient, and the country and population size is displayed when the user hovers over the country.
\tabular{c}{
\figure{F19}{options: width=5in}
}
}
\references{
Gesmann, M. & de Castillo, D. (2011) googleVis: Interface between R and the Google Visualisation API. \emph{The R Journal}, 3(2): 40-44. \url{https://journal.r-project.org/archive/2011-2/RJournal_2011-2_Gesmann+de~Castillo.pdf}.

Gesmann, M. & de Castillo, D. (2015) R Interface to Google Charts. R package version 0.5.8. Available at: \url{https://CRAN.R-project.org/package=googleVis}.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.
}
\examples{
\dontrun{
#Example 1

data(Z4)

F27(data=Z4, locationvar="LatLong", numvar="Magnitude",
hovervar="Depth", dataMode="markers")

#Example 2

data(Z5)

F27(data=Z5, locationvar="Country", numvar="Population",
hovervar="Country")
}
}
\keyword{F27}
