\name{F29}
\alias{F29}
\encoding{latin1}
\title{TAYLOR DIAGRAM}
\description{Display a Taylor diagram, which is used to determine the quality of model predictions against the reference values, typically direct observations.}
\usage{
F29(data, ref, models, pos.cor=TRUE, TAYLOR=NULL, ResetPAR=TRUE, PAR=NULL,
COLOR=NULL, PCH=NULL, CEXPCH=1.4, LEGEND=NULL, MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{ref}{The refrence values, typically observed values.}
  \item{models}{The predicted values by the models.}
  \item{pos.cor}{Whether to display only positive (TRUE) or all values of correlation (FALSE).}
  \item{TAYLOR}{It allows to specify the characteristics of the function \link[plotrix]{taylor.diagram}.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{COLOR}{Vector with the color symbol of the models.}
  \item{PCH}{Vector with the symbols of the graphic. If NULL, they are automatically calculated starting with the symbol 15.}
  \item{CEXPCH}{Size of the graphic symbols.}
  \item{LEGEND}{It allows to include a legend to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
}
\value{A Taylor diagram is obtained.}  
\details{
This plot allows to select the best model by plotting all models against a reference values (Taylor, 2011), which are typycally the observed values.

Two displays are available. One displays the entire range of correlations from -1 to 1 by setting the argument \emph{pos.cor=FALSE}. When \emph{pos.cor=TRUE}, only the range from 0 to 1 will be displayed.

\strong{FUNCTIONS}

The plot is performed with the function \link[plotrix]{taylor.diagram} of the package plotrix (Lemon et al., 2015). For further details see the help of the function \link[plotrix]{taylor.diagram} and/or Guisande & Vammonde (2012).

\strong{EXAMPLES}

The data are monthly values of temperature and temperature predicted by different models. The aim is to determine which is the best model using the Taylor diagram (Taylor, 2001).

In the Taylor diagram, the models are compared based on correlation coefficient, amplitude variation (standard deviation) and the Root-mean-square error (RMS).

The correlation coefficient is shown in the right graph outer arc (values range from -1 to 1 with the argument \emph{pos.cor=FALSE} and from 0 to 1 with the argument \emph{pos.cor=FALSE}).

The dotted arcs show the values of the standard deviation (values from 0 to 10 in this example). The arc that is not dotted with an approximate value of 6.35 shows the standard deviation of the observed values and is used as reference. Finally, the arcs with values of 10 and 5, are the RMS.

The best model is the one with a higher coefficient of correlation, a value of RMS smaller and standard deviation closer to the standard deviation of the observed values, which in this example is a line showing a standard deviation of 6.35. Therefore, the model with the blue triangle symbol, model 3, is the most predictive.

\strong{Example 1.} The first diagram displays the entire range of correlations from -1 to 1 with the argument \emph{pos.cor=FALSE}).
\tabular{c}{
\figure{F13}{options: width=4in}
}
\strong{Example 2.} The second diagram displays only the range from 0 to 1 (default option).
\tabular{c}{
\figure{F14}{options: width=4in}
}
}
\references{
Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Lemon, J., Bolker, B., Oom, S., Klein, E., Rowlingson, B., Wickham, H., Tyagi, A., Eterradossi, O., Grothendieck, G., Toews, M., Kane, J., Turner, R., Witthoft, C., Stander, J., Petzoldt, T., Duursma, R., Biancotto, E., Levy, O., Dutang, C., Solymos, P., Engelmann, R., Hecker, M., Steinbeck, F., Borchers, H., Singmann, H., Toal, T. & Ogle, D. (2015) Various plotting functions. R package version 3.5-11. Available at: \url{https://CRAN.R-project.org/package=plotrix}.

Taylor, K.E. (2001) Summarizing multiple aspects of model performance in a single diagram. \emph{Journal of Geophysical Research}, 106: 7183-7192.
}
\examples{
\dontrun{

data(Z2)

#Example 1.

F29(data=Z2, ref="Observed", models=c("Model1","Model2",
"Model3","Model4"), pos.cor=FALSE)

#Example 2.

F29(data=Z2, ref="Observed", models=c("Model1","Model2","Model3","Model4"))
}
}
\keyword{F29}
