\name{F31}
\alias{F31}
\encoding{latin1}
\title{3D SURFACE GRADIENT PLOTS}
\description{Display a 3D surface gradient plot with variable Z as a column.}
\usage{
F31(data, X, Y, Z, theta=120, phi=20, ticktype="detailed", scale=TRUE,
type="mgcv", DPLOT=NULL, ResetPAR=TRUE, PAR=NULL, XLAB=NULL, YLAB=NULL,
ZLAB=NULL, XLIM=NULL, YLIM=NULL, ZLIM=NULL, COLOR=rainbow, LEGEND=NULL,
MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{X}{Variable X.}
  \item{Y}{Variable Y.}
  \item{Z}{Variable Z.}
  \item{theta}{Angle defining the azimuthal direction.}
  \item{phi}{Angle defining the colatitude direction.}
  \item{ticktype}{Character: "simple" draws just an arrow parallel to the axis to indicate direction of increase and "detailed" draws normal ticks as per 2D plots.}
  \item{scale}{If it is TRUE the X, Y and Z variables are transformed separately. If scale is FALSE the coordinates are scaled so that aspect ratios are retained.}
  \item{type}{Type of interpolation method. The options are "akima", "mba" and "mgcv". For details see the same argument of the \link[R2BayesX]{plot3d}.}
  \item{DPLOT}{It allows to specify the characteristics of the function \link[R2BayesX]{plot3d}.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{ZLAB}{Legend of the Z axis.}
  \item{XLIM}{Vector with the limits of the X axis.}
  \item{YLIM}{Vector with the limits of the Y axis.}
  \item{ZLIM}{Vector with the limits of the Z axis.}
  \item{COLOR}{Color of the surface.}
  \item{LEGEND}{It allows to include a legend to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
}
\value{A 3D surface gradient plot is obtained.}  
\details{
\strong{FUNCTIONS}

The plot is performed with the function \link[R2BayesX]{plot3d} of the base package graphics R2BayesX (Umlauf et al., 2015a; 2015b).

\strong{EXAMPLES}

\strong{Example 1.} Geographical records and altitude of fish freshwater species of the genus Cyphocharax.
\tabular{c}{
\figure{F64}{options: width=4.5in}
}
\strong{Example 2.} Depth in a coastal area close to Japan.
\tabular{c}{
\figure{F63}{options: width=4.5in}
}
}
\references{
Umlauf, N., Adler, D., Kneib, T., Lang, S., Zeileis, A. (2015a). Structured Additive Regression Models: An R Interface to BayesX. \emph{Journal of Statistical Software}, 63(21), 1-46. \url{http://www.jstatsoft.org/v63/i21/}.

Umlauf, N., Kneib, T., Lang, S. & Zeileis, A.(2015b) Estimate Structured Additive Regression Models with BayesX. R package version 1.0-0. Available at: \url{https://CRAN.R-project.org/package=R2BayesX}.
}
\examples{
\dontrun{

#Example 1

data(Z12)

F31(data=Z12, X="Latitude", Y="Longitude", Z="Altitude")

#Example 2

data(Z11)

F31(data=Z11, X="Latitude", Y="Longitude", Z="Depth")
}
}
\keyword{F31}
