\name{F32}
\alias{F32}
\encoding{latin1}
\title{LINE CHARTS FOR VARIABLE X QUANTITATIVE}
\description{It performs a simple line chart with or without text labels and a regression model.}
\usage{
F32(data, varY,  varX, textlabel=NULL, type="b", label=NULL, reg=FALSE,
model="Linear", outliers=FALSE, quant1=0.05, quant2 = 0.95,  ci=TRUE,
level=0.95, ResetPAR=TRUE, PAR=NULL, XLAB=NULL, YLAB=NULL, COLOR="black",
COLORR="red", PCH=16, lty=1, ltyci=2,  ltyL=1, lwd=2.5, lwdL=1, R2.pos="topleft",
PLOT=NULL, LEGEND=NULL, AXIS=NULL, MTEXT= NULL, TEXT=NULL,
dec=",", file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Quantitative independent variable.}
  \item{textlabel}{Variable with the text labels.}
  \item{type}{Character string giving the type of plot desired. The following values are possible: "p" for points, "l" for lines, "b" for both points and lines, "c" for empty points joined by lines, "o" for overplotted points and lines, "s" and "S" for stair steps and "h" for histogram-like vertical lines. Finally, "n" does not produce any points or lines.}
  \item{label}{It allows to specify the characteristics of the text labels with the function \link[graphics]{text}.}
  \item{reg}{If TRUE a regression model is performed.}
  \item{model}{One regression model can be selected: "Linear" , "Log", "S-curve", "Power", "Exp", "Quadratic", "Cubic", "Inverse".  It is not considered the model in those cases in which there is the logarithm that apply to any of the variables, if any value of the variable, which applies the logarithm, is zero or negative. The inverse model is not calculated if any value of the independent variable is zero.}
\item{outliers}{If it is TRUE, the outliers are removed using the selected regression model.}
  \item{quant1}{Quantile of the lower end to the elimination of outliers.}
  \item{quant2}{Quantile of the upper end to the elimination of outliers.}
  \item{ci}{If it is TRUE the confidence interval is depicted, but only for the linear regression model.}
  \item{level}{Tolerance/confidence level.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{COLOR}{Color of the symbols.}
  \item{COLORR}{Color of the line of the regression model.}
  \item{PCH}{Graphic symbol (see the description of the same argument in the function \link{F1}).}
  \item{lty}{Type of the regression line (see the description of the same argument in the function \link{F1}).}
  \item{ltyci}{Type of the confidence interval line (see figure of the argument \emph{lty} in the function \link{F1}).}
  \item{ltyL}{Type of the line chart (see figure of the argument \emph{lty} in the function \link{F1}).}
  \item{lwd}{Line width of the regression line relative to the default (default=1), so 2 is twice as wide.}
  \item{lwdL}{Line width of the chart relative to the default (default=1), so 2 is twice as wide.}
  \item{R2.pos}{If it is not NULL, with this argument is possible to specify the position of the \eqn{r^2} of the regression in the scatter plot.}
  \item{PLOT}{It allows to specify the characteristics of the function \link[graphics]{plot.default}.}
  \item{LEGEND}{It allows to include a legend to the graph.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
  \item{dec}{It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{file}{TXT FILE. If the argument \emph{reg=TRUE} a TXT file is saved with the information of the regression.}
}
\value{A simple line chart with or without linear regression is obtained.}  
\details{
\strong{FUNCTIONS}

The plot is performed with the function \link[graphics]{plot.default} of base graphics package and the linear regression with the function \link[stats]{lm} of base stats package. The function \link[nortest]{lillie.test} of the package nortest (Gross, 2013) is used to perform the test of Normality Kolmogorov-Smirnov with Lilliefors'correction, the function \link[lmtest]{dwtest} of the package lmtest (Hothorn et al., 2013) to analyze the autocorrelation with the test and the Durbin-Watson statistic function \link[lmtest]{bptest} of the package lmtest (Hothorn et al., 2013) to perform the Breusch-Pagan test of homoscedasticity.

\strong{EXAMPLES}
The data are monthly mean temperature for 1990 and 2000 in three cities in Spain: Huelva, Palma de Mallorca and Vigo. They were obtained from the Agencia Estatal de Meteorologa of Spain \url{http://www.aemet.es/es/portada}.

\strong{Example 1} Monthly temperature in Palma de Mallorca in the year 2000. Text labels are assigned to the points with the argument \emph{textlabel="Season"}. Moreover, a different color is assigned to each text label using a variable with colors.
\tabular{c}{
\figure{F65}{options: width=3.2in}
}
\strong{Example 2} Monthly temperature in Huelva in the year 2000 without text labels.
\tabular{c}{
\figure{F66}{options: width=3.2in}
}
\strong{Example 3} A linear regression line is added with the argument \emph{reg=TRUE}.
\tabular{c}{
\figure{F67}{options: width=5in}
}
}
\references{
Durbin, J. & Watson G.S. (1951) Testing for serial correlation in least squares regression. \emph{Biometrika}, \strong{38}, 159-171.

Gross, J. (2013) Tests for Normality. R package version 1.0-2. Available at: \url{https://CRAN.R-project.org/package=nortest}.

Hothorn, T. et al., (2013) Testing Linear Regression Models. R package version 0.9-33. Available at: \url{https://CRAN.R-project.org/package=lmtest}.
}
\examples{
\dontrun{

#Example 1

data(Z13)

data<-subset(Z13,(City == "Palma de Mallorca") &  (Year == 2000))

color<-as.character(data[,"Color"])

F32(data=data, varY="Temperature", varX="Month", textlabel="Season",
label = c("pos = 3" , "col = color"), TEXT = c("x = 3" , "y=25",
"labels = 'Palma de Mallorca\n2000'", "font=2", "cex=1.3"))

#Example 2

data(Z13)

data<-subset(Z13,(City == "Huelva") &  (Year == 2000))

F32(data=data, varY="Temperature", varX="Month", COLOR="red", ltyL=2,
TEXT = c("x = 2" , "y=25", "labels = 'Huelva\n2000'", "font=2", "cex=1.3"))

#Example 3

data(Z13)

data<-subset(Z13,(City == "Vigo") &  (Year == 1990))

F32(data=data, varY="Temperature", varX="Month", reg=TRUE, model="Cubic",
COLOR="red", COLORR="black", ltyL=2, TEXT=c("x=11.5", "y=20", "labels = 'Vigo\n1990'",
"font=2", "cex=1.3"))
}
}
\keyword{F32}
