\name{F39}
\alias{F39}
\encoding{latin1}
\title{MULTIPLE DOT OR MEAN WITH ERROR BARS LINE CHARTS FOR VARIABLE X QUALITATIVE}
\description{It performs a multiple dot or mean with error bars line charts for variable X qualitative.}
\usage{
F39(data, varY, FactorX, group, type="b", method="mean", dev="sd",
ResetPAR=TRUE, PAR=NULL, order=NULL, OrderCat=NULL, LabelCat=NULL,
XLAB=NULL, YLAB=NULL, XLIM=NULL, YLIM=NULL, COLOR=NULL, COLORI="black",
ltyL=NULL, lwdL=1,PCH=NULL, CEX=1, LEGEND=NULL, AXIS=NULL,MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{FactorX}{Qualitative independent variable.}
  \item{group}{Variable with the categories to be grouped.}
  \item{type}{Character string giving the type of plot desired. The possible values are shown in the same argument of function \link{F38}.}
  \item{method}{If it is not NULL, the average of each category of the independent variable \emph{FactorX} is estimated with the "mean" or the "median".}
  \item{dev}{If the argument \emph{method} is not NULL, the error bars may be estimated using the standard deviation ("sd") or the standard error ("se").}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{order}{If it is NULL the categories are ordered as found in the variable \emph{FactorX}, if it is "increasing" are ordered from lesser to greater median or mean according to the method selected in the argument \emph{method}, if it is "decreasing" are ordered from greater to lesser median or mean, if it is "alhaAZ" are ordered from A to Z and if it is "alphaZA" from Z to A.} 
  \item{OrderCat}{It allows to specify a vector with the order in which the categories are shown. If this argument is specified, the argument \emph{order} is not taken into account.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{XLIM}{Vector with the limits of the X axis.}
  \item{YLIM}{Vector with the limits of the Y axis.}
  \item{COLOR}{Color of the symbols. It must be as many as different categories of the variable \emph{group}.}
  \item{COLORI}{Color of the error bars.}
  \item{ltyL}{Type of the line chart (see figure of the argument \emph{lty} in the function \link{F1}).}
  \item{lwdL}{Line width of the line chart.}
  \item{PCH}{Graphic symbol (see the description of the same argument in the function \link{F1}). It must be as many as different categories of the variable \emph{group}.}
  \item{CEX}{Size of the symbols.}
  \item{LEGEND}{It allows to modify the legend of the graph.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
}
\value{A multiple dot or mean line charts for variable X qualitative are obtained.}  
\details{
\strong{FUNCTIONS}

The plot is performed with the functions \link[graphics]{boxplot}, \link[graphics]{points} and \link[graphics]{arrows} of base graphics package. For further details see Guisande & Vammonde (2012).

\strong{EXAMPLES}

In an experiment conducted with expert tasters and people who had no experience tasting, they were taught to identify 15 types of wines from different regions. Variations in ability to ascertain the wine provenance over time was measured between experts and non-experts. For every time, each person assessed a large number of samples and the degree of success was recorded on a scale of 0 to 12.

\strong{Example 1} A dot plot is depicted with the argument \emph{method=NULL} of the variable Success for all times grouped by the experience of tasters.
\tabular{c}{
\figure{F86}{options: width=3.2in}
}
\strong{Example 2} The mean and the standard deviation of the variable Success is obtained for each time and group of tasters.
\tabular{c}{
\figure{F87}{options: width=3.8in}
}
}
\references{
Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.
}
\examples{
\dontrun{

#Example 1

data(Z15)

F39(data=Z15, varY="Success", FactorX="Time", group="Experience",
method=NULL, YLIM=c(0,14))

#Example 2

data(Z15)

F39(data=Z15, varY="Success", FactorX="Time", group="Experience",
YLIM=c(0,14))
}
}
\keyword{F39}
