\name{F45}
\alias{F45}
\encoding{latin1}
\title{MONTE-CARLO TEST FOR TWO VARIABLES}
\description{A Monte-Carlo test is performed for testing the hypothesis, in two variable, if an observation is significantly greater or lower than a set of values belonging to a group.}
\usage{
F45(data, variable1, variable2, group, group1, row, ResetPAR=TRUE,
PAR=NULL, BIVTEST=NULL, Pcol="red", colbiv="lightblue", br=20, sub="", LEGEND=NULL,
AXIS=NULL, MTEXT= NULL, TEXT=NULL, TEXTX=NULL, TEXTY=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{variable1}{Variable 1 to be selected.}
  \item{variable2}{Variable 2 to be selected.}
  \item{group}{Variable with the groups to be compared.}
  \item{group1}{Group to be selected within the variable \emph{group}.}
  \item{row}{Row number of the observation to be compared with the \emph{group1}.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{BIVTEST}{It accesses the function \link[adehabitatHS]{biv.test} of the package adehabitatHS, which performs the bivariate plot that displays the results of a bivariate Monte-Carlo test.}
  \item{Pcol}{Color or name for the observation in the BIVTEST plot.}
  \item{colbiv}{Color or name of all values of group 1 in the BIVTEST plot.}
  \item{br}{Numbers of breaks of the histograms in the BIVTEST plot.}
  \item{sub}{Title in the BIVTEST plot.}
  \item{LEGEND}{It allows to modify the legend of the BIVTEST plot.}
  \item{AXIS}{It allows to add axes to the BIVTEST plot.}
  \item{MTEXT}{It allows to add text on the margins of BIVTEST plot.}
  \item{TEXT}{It allows to add text in any area of the inner part of the BIVTEST plot.}
  \item{TEXTX}{It allows to modify the lengend of axis X.}
  \item{TEXTY}{It allows to modify the lengend of axis Y.}
}
\value{It is depicted a bivariate plot that displays the results of a bivariate Monte-Carlo test.}  
\details{
In the Monte-Carlo test, if the alternative hypothesis is \emph{greater}, a p-value is estimated as: (number of random values equal to or greater than the observed one + 1)/(number of permutations + 1). The null hypothesis is rejected if the p-value is less than the significance level.

If the alternative hypothesis is \emph{smaller}, a pvalue is estimated as: (number of random values equal to or less than the observed one + 1)/(number of permutations + 1). Again, the null hypothesis is rejected if the p-value is less than the significance level. 

\strong{FUNCTIONS}

The Monte-Carlo test was performed with the function \link[ade4]{as.randtest} of the package ade4 (Chessel et al., 2004; Dray et al., 2007; 2015). The bivariate plot that displays the results of a bivariate Monte-Carlo test, for which the p-values are computed with the function \link[ade4]{as.randtest} (one-sided tests), was performed with the function \link[adehabitatHS]{biv.test} of the package adehabitatHS (Calenge, 2006; 2015). 

\strong{EXAMPLES}

For the example, morphometric data of three families of freshwater fishes, as the distance from the origin of the dorsal fin to the origin of the anal fin (M13), the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010).

In the example the morphometric variables M12 and M15 are compared between the observation of the row number 54, a individual of the species \emph{Triportheus magdalenae}, and all values of the species \emph{Triportheus angulatus}.

For the variable M15 p = 0.278 and, therefore, there are not significant differences between the observation of the species \emph{Triportheus magdalenae} and the individuals of the species \emph{Triportheus angulatus}.

However, for the variable M12 p = 0.056 and, therefore, it may be concluded that the observation is significantly different than all individuals of the species \emph{Triportheus angulatus}.
\tabular{c}{
\figure{F98}{options: width=4.7in}
}
}
\references{
Calenge, C. (2006) The package adehabitat for the R software: a tool for the analysis of space and habitat use by animals. \emph{Ecological Modelling}, 197, 516-519.

Calenge, C. (2015) Analysis of Habitat Selection by Animals. R package version 0.3-12. Available at: \url{https://CRAN.R-project.org/package=adehabitatHS}.

Chessel, D. and Dufour, A.B. and Thioulouse, J. (2004) The ade4 package-I- One-table methods. \emph{R News}, 4, 5-10.

Dray, S. & Dufour, A.B. (2007) The ade4 package: implementing the duality diagram for ecologists. \emph{Journal of Statistical Software}, 22(4), 1-20.

Dray, S. & Dufour, A.B. and Chessel, D. (2007) The ade4 package-II: Two-table and K-table methods. \emph{R News}, 7(2), 47-52.

Dray , S., Dufour , A-B. & Thioulouse , J. (2015) Analysis of Ecological Data : Exploratory and Euclidean Methods
in Environmental Sciences. R package version 1.7-2. Available at: \url{https://CRAN.R-project.org/package=ade4}.

Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.
}
\examples{
\dontrun{

data(Z1)

F45(data=Z1, variable1="M12", variable2="M15", group="Species",
group1="Triportheus angulatus", row=54, LEGEND = c("x='topright'",
"legend=dati", "col=col", "bty = 'n'", "pch=c(16,16)", "text.font=3"))
}
}
\keyword{F45}
