\name{F46}
\alias{F46}
\encoding{latin1}
\title{POLAR COORDINATES}
\description{This function calculates the polar coordinates of several variables.}
\usage{
F46(data, variables, group=NULL, cor=TRUE, ellipse=FALSE, convex=FALSE,
SCATTERPLOT=NULL, ResetPAR=TRUE, PAR=NULL, XLAB=NULL, YLAB=NULL, XLIM=NULL,
YLIM=NULL, PCH=NULL, COLOR=NULL, LEGEND=NULL, MTEXT= NULL, TEXT=NULL,
arrows=TRUE, larrow=1, ARROWS=NULL, TEXTa=NULL, file="Polar coordinates.csv",
na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{variables}{Variables to be selected. If qualitative variables are used as independent variables, they must be put into a countable number of categories, i.e., the names of the categories must be numbers.}
  \item{group}{Variable with the groups to be discriminated.}
  \item{cor}{If it is TRUE the variables are ordered according to the correlation between them when estimating the polar coordinates. Therefore, the next variable to another variable is the one that has a greater positive correlation.}
  \item{ellipse}{If it is TRUE the ellipses with the levels of significance to the 0.5 (inner ellipse) and 0.95 (outer ellipse) of each category of the variable \emph{group} is depicted. These levels of significance can be modified by entering the function \link[car]{scatterplot} using the argument \emph{SCATTERPLOT} and modifying the argument \emph{levels=c(0.5,0.95)}.}
  \item{convex}{If it is TRUE the convex hull is depicted for each category.}
  \item{SCATTERPLOT}{It accesses the function \link[car]{scatterplot} of the car package, with the graph \emph{biplot}.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{XLIM}{Vector with the limits of the X axis.}
  \item{YLIM}{Vector with the limits of the Y axis.}
  \item{PCH}{Vector with the symbols, that should be as many as different groups the variable \emph{group} has. If NULL, they are automatically calculated starting with the symbol 15.}
  \item{COLOR}{It allows to modify the colors of the scatterplot. It must be as many as different categories of the variable \emph{group}.}
  \item{LEGEND}{It allows to modify the legend of the scatterplot.}
  \item{MTEXT}{It allows to add text on the margins of the scatterplot.}
  \item{TEXT}{It allows to add text in any area of the inner part of the scatterplot.}
  \item{arrows}{If it is TRUE the arrows are shown in the scatterplot with the polar coordinates. These arrows show the vector of the variables selected when calculating the polar coordinates.}
  \item{larrow}{It modifies the length of the arrows.}
  \item{ARROWS}{It accesses the function \link[IDPmisc]{Arrows} of the package IDPmisc, which performs the arrows.}
  \item{TEXTa}{It allows to modify the labels at the end of the arrows.}
  \item{file}{CSV FILES. Filename with the polar coordinates.}
  \item{na}{CSV FILE. Text that is used in the cells without data.}
  \item{dec}{CSV FILE. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILE. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{It is depicted a scatter plot with the polar coordinates, which are also saved in a CSV file.}
\details{
\strong{Polar coordinates}

All variables are transformed to a scale ranged between -1 and 1. For each value the X and Y polar coordinates are estimated using the following equations:
\tabular{ll}{
\eqn{X=\displaystyle\sum_{i=1}^{n}|z_j|cos(\alpha)} \tab \eqn{Y=\displaystyle\sum_{i=1}^{n}|z_j|sin(\alpha)}
}
where \emph{z} is the value of the variable \emph{j} and \emph{n} the number of variables. 

Each variable is assigned an angle (\eqn{\alpha}). The increment value of the angle is always \eqn{\frac{360}{n*2}}. If for instance the number of variables are 5, the increment angle is 36. Therefore, for the first variable if the value is \eqn{\geq0} the \eqn{\alpha} value is 36 and if the value is \eqn{<0} the value is 36+180, for the second variable if the value is \eqn{\geq0} the \eqn{\alpha} value is 36+36 and if the value is \eqn{<0} the value is 36+36+180, etc. Degrees to radians angle conversion is carried out assuming that 1 degree = 0.0174532925 radians.

Therefore, the order of the variables is important because a different alpha value is assigned. If the argument \emph{cor=TRUE}, the order is established calculating the correlation matrix of the variables, and ordering them in the way that each variable will be followed by the variable to which is highly correlated. The goal is to favor a larger dispersion of the data in the resulting polar coordinates system.

\strong{FUNCTIONS}

The arrows are depicted with the function \link[IDPmisc]{Arrows} of the package IDPmisc (Locher & Ruckstuhl, 2014). The scatterplot is performed with the function \link[car]{scatterplot} of the car package (Fox & Weisberg, 2011; Fox et al., 2014). The convex hull is estimated with the function \link[grDevices]{chull} of the package grDevices.

\strong{EXAMPLES}

For the example, morphometric data of three families of freshwater fishes, as the distance from the origin of the dorsal fin to the origin of the anal fin (M13), the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010).

Figure shows the plots obtained in an example comparing the genera \emph{Bryconops} and \emph{Ctenobrycon}, with the variables M9, M10 and M6.
\tabular{c}{
\strong{Example 1}\cr
\figure{F99}{options: width=3.3in}
}
}
\references{
Fox, J. & Weisberg, S. (2011) An R Companion to Applied Regression, Second Edition. Thousand Oaks CA: Sage. \url{ http://socserv.socsci.mcmaster.ca/jfox/Books/Companion}.

Fox, J., Weisberg, S., Adler, D., Bates, D., Baud-Bovy, G., Ellison, S., Firth, D., Friendly, M., Gorjanc, G., Graves, S., Heiberger, R., Laboissiere, R., Monette, G., Murdoch, D., Nilsson, H., Ogle, D., Ripley, B., Venables, W. & Zeileis, A. (2014) Companion to Applied Regression. R package version 2.0-20. Available at: \url{https://CRAN.R-project.org/package=car}.

Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.

Locher, R. & Ruckstuhl, A. (2014) Utilities of Institute of Data Analyses and Process Design. R package version 1.1.17. Available at: \url{https://CRAN.R-project.org/package=IDPmisc}.

}
\examples{
\dontrun{

data(Z1)

Z1<-subset(Z1,(Genus == "Bryconops") | (Genus == "Ctenobrycon"))

F46(data=Z1, variables=c("M9","M10","M6"), group="Genus", ellipse=TRUE,
LEGEND=c("x='topleft'", "legend=unique(datosF[,'Group'])",
"col=color1", "pch=pcht", "bty='n'", "cex=1.2", "text.font=3") )
}
}
\keyword{F46}
