\name{F51}
\alias{F51}
\encoding{latin1}
\title{BIPLOTS}
\description{It performs biplots with one or two matrices.}
\usage{
F51(data, varY.1, varX.1, cat.1, varY.2=NULL, varX.2=NULL, cat.2=NULL,
labels=NULL, scale=TRUE, ellipse=FALSE, convex=FALSE, SCATTERPLOT=NULL,
LABEL=NULL, ResetPAR=TRUE, PAR=NULL, XLAB=NULL, YLAB=NULL, XLIM1=NULL,
YLIM1=NULL, PCH=NULL, COLOR=NULL, LEGEND=NULL, MTEXT= NULL, TEXT1=NULL,
ARROWS=NULL, XLIM2=NULL, YLIM2=NULL, TEXT2=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{varY.1}{Variable Y of matrix 1.}
  \item{varX.1}{Variable X of matrix 1.}
  \item{cat.1}{Variable of matrix 1 with the groups to be discriminated.}
  \item{varY.2}{Variable Y of matrix 2, which is depicted with arrows.}
  \item{varX.2}{Variable X of matrix 2, which is depicted with arrows}
  \item{cat.2}{Variable of matrix 2 with the text at the end of the arrows.}
  \item{labels}{Variable of matrix 1 with the text labels.}
  \item{scale}{If it is TRUE the scale of matrix 2, which is depicted with arrows, it is adjusted to the scale of matrix 1.}
  \item{ellipse}{If it is TRUE the ellipses with the levels of significance to the 0.5 (inner ellipse) and 0.95 (outer ellipse) of each category of the variable \emph{cat.1} is depicted. These levels of significance can be modified by entering the function \link[car]{scatterplot} using the argument \emph{SCATTERPLOT} and modifying the argument \emph{levels=c(0.5,0.95)}.}
  \item{convex}{If it is TRUE the convex hull is depicted for each category.}
  \item{SCATTERPLOT}{It accesses the function \link[car]{scatterplot} of the car package, with the graph \emph{biplot}.}
  \item{LABEL}{It allows to specify the characteristics of the text labels of the argument \emph{labels}, with the function \link[graphics]{text}.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{XLIM1}{Vector with the limits of the X axis in the matrix 1.}
  \item{YLIM1}{Vector with the limits of the Y axis in the matrix 1.}
  \item{PCH}{Vector with the symbols, that should be as many as different groups the variable \emph{cat.1} has. If NULL, they are automatically calculated starting with the symbol 15.}
  \item{COLOR}{It allows to modify the colors of the scatterplot. It must be as many as different categories of the variable \emph{cat.1}.}
  \item{LEGEND}{It allows to modify the legend of the scatterplot.}
  \item{MTEXT}{It allows to add text on the margins of the scatterplot.}
  \item{TEXT1}{It allows to add text in any area of the inner part of the scatterplot.}
  \item{ARROWS}{It accesses the function \link[IDPmisc]{Arrows} of the package IDPmisc, which performs the arrows.}
  \item{XLIM2}{Vector with the limits of the X axis in the matrix 2.}
  \item{YLIM2}{Vector with the limits of the Y axis in the matrix 2.}
  \item{TEXT2}{It allows to modify the labels at the end of the arrows.}

}
\value{It is depicted a biplot with one or two matrices.}
\details{
\strong{FUNCTIONS}

The arrows are depicted with the function \link[IDPmisc]{Arrows} of the package IDPmisc (Locher & Ruckstuhl, 2014).

The scatterplot is performed with the function \link[car]{scatterplot} of the car package (Fox & Weisberg, 2011; Fox et al., 2014).

The convex hull is estimated with the function \link[grDevices]{chull} of the package grDevices.

\strong{EXAMPLES}

The dataset is the output of a Principal Component Analysis (PCA) of a study carried out with demographic parameters of 57 countries in Europe, Africa and America. The variables used were male and female life expectancy at birth (in years of life), the mortality rates, infant mortality, birth, and fertility, the gross domestic product per capita (in thousands of dollars per year) and the literacy rate for men and women (in percentage) in the year 2000. The data were obtained from The World Bank \url{http://www.worldbank.org/}.

\strong{Example 1} Biplot with the scores of the axes 1 and 2 of the PCA, where the categories are the continents and the ellipses are shown with the argument \emph{ellipse=TRUE}.
\tabular{c}{
\figure{F110}{options: width=3.8in}
}
\strong{Example 2} As the example 1 but the scores are labeled with the countries using the argument \emph{labels="Country"}.
\tabular{c}{
\figure{F111}{options: width=3.8in}
}
\strong{Example 3} As the example 1 but a second matrix is added with the position of the variables in the PCA and the convex hull is depicted for each category with the argument \emph{convex=TRUE}.
\tabular{c}{
\figure{F112}{options: width=3.8in}
}
}
\references{
Fox, J. & Weisberg, S. (2011) An R Companion to Applied Regression, Second Edition. Thousand Oaks CA: Sage. \url{ http://socserv.socsci.mcmaster.ca/jfox/Books/Companion}.

Fox, J., Weisberg, S., Adler, D., Bates, D., Baud-Bovy, G., Ellison, S., Firth, D., Friendly, M., Gorjanc, G., Graves, S., Heiberger, R., Laboissiere, R., Monette, G., Murdoch, D., Nilsson, H., Ogle, D., Ripley, B., Venables, W. & Zeileis, A. (2014) Companion to Applied Regression. R package version 2.0-20. Available at: \url{https://CRAN.R-project.org/package=car}.

Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.

Locher, R. & Ruckstuhl, A. (2014) Utilities of Institute of Data Analyses and Process Design. R package version 1.1.17. Available at: \url{https://CRAN.R-project.org/package=IDPmisc}.

}
\examples{
\dontrun{

#Example 1

data(Z18)

F51(data=Z18, varY.1="PC2.1", varX.1="PC1.1", cat.1="Continent", ellipse=TRUE)

#Example 2

data(Z18)

F51(data=Z18, varY.1="PC2.1", varX.1="PC1.1", cat.1="Continent", ellipse=TRUE,
labels="Country")

#Example 3

data(Z18)

F51(data=Z18, varY.1="PC2.1", varX.1="PC1.1", cat.1="Continent", convex=TRUE,
varY.2="PC2.2", varX.2="PC1.2", cat.2="Variables")
}
}
\keyword{F51}
