\name{F52}
\alias{F52}
\encoding{latin1}
\title{POPULATION PYRAMID PLOT}
\description{It performs a population pyramid plot for many variables.}
\usage{
F52(data, lbars, rbars, labels, toplabels=c("Males","Age","Females"),
showvalues=0, PYRAMIDPLOT=NULL, ResetPAR=TRUE, PAR=NULL, XLIM=NULL,
COLOR=NULL, LEGEND=NULL, MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{lbars}{Variable or variables to be located in the right bars.}
  \item{rbars}{Variable or variables to be located in the left bars. There must be the same number than those of \emph{lbars}.}
  \item{labels}{Variable with the labels for the categories represented by each pair of bars.}
  \item{toplabels}{The names represented on the left and right sides of the plot and a heading for the labels in the center.}
  \item{showvalues}{If it is 0 the values are not represented, if it is 1 the values of the first set \emph{lbars[1]} and \emph{lbars[1]} are shown, if it is 2 the values of the second set \emph{lbars[2]} and \emph{lbars[2]} are shown, etc.}
  \item{PYRAMIDPLOT}{It accesses the function \link[plotrix]{pyramid.plot} that allows to modify the population plot.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLIM}{Vector with two values, with the maximum values for left bars and right bars.}
  \item{COLOR}{Color of bars. It must be as many as different variables of \emph{lbars} and \emph{rbars}. As the color has transparency, the plot must be copy as bitmap and not metafile.}
  \item{LEGEND}{It allows to modify the legend to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
}
\value{A population pyramid plot is obtained.}
\details{
\strong{FUNCTIONS}

The plot is performed with the functions \link[plotrix]{pyramid.plot} of the package plotrix (Lemon et al., 2015). For further details see Guisande & Vammonde (2012).

\strong{EXAMPLES}

Human population density by sex and age group in Spain for the years 1900 and 1991. Data were obtained from the Spanish Statistical Office \url{http://www.ine.es}. An array (matrix) with 7 columns: Age group, males in 1900, females in 1900, males in 1991, females in 1991, foreign males in 1991 and foreign females in 1991.
\tabular{c}{
\figure{F113}{options: width=4.1in}
}
\strong{Example 1} It is depicted the males, females and foreigners in 1991. The colors are modified with the argument \emph{COLOR} and the legend with the argument \emph{LEGEND}. With the argument \emph{showvalues=1} is indicated to show the values of the first set of data, in this case M.1991 and F.1991, so the first variable for both \emph{lbars} and \emph{rbars}.

\strong{Example 2} The default options are used with the exception that, with the argument \emph{showvalues=2}, it is depicted the values of the second set of data, in this case MF.1991 and FF.1991, so the second variable for both \emph{lbars} and \emph{rbars}.
\tabular{c}{
\figure{F114}{options: width=5in}
}
}
\references{
Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Lemon, J., Bolker, B., Oom, S., Klein, E., Rowlingson, B.,Wickham, H., Tyagi, A., Eterradossi, O., Grothendieck, G., Toews, M., Kane, J., Turner, R., Witthoft, C., Stander, J., Petzoldt, T., Duursma, R., Biancotto, E., Levy, O., Dutang, C., Solymos, P., Engelmann, R., Hecker, M., Steinbeck, F., Borchers, H., Singmann, H., Toal, T. & Ogle, D. (2015) Various plotting functions. R package version 3.5-11. Available at: https://CRAN.R-project.org/package=plotrix.
}
\examples{
\dontrun{

#Expample 1

data(Z7)

F52(data=Z7, lbars=c("M.1991","MF.1991"), rbars=c("F.1991","FF.1991"),
labels="Age", showvalues=1, COLOR=c("blue","red","pink","red"),
LEGEND = c("x = 'topleft'","legend=c('Males', 'Females', 'Foreigners')",
"col=c('blue','pink','red')" , "pch = 15" , "bty = 'n'"))

#Expample 2

data(Z7)

F52(data=Z7, lbars=c("M.1991","MF.1991"), rbars=c("F.1991", "FF.1991"),
labels="Age", showvalues=2)
}
}
\keyword{F52}
