\name{F56}
\alias{F56}
\encoding{latin1}
\title{MOSAIC PLOT}
\description{It performs a mosaic plot of a contingency table.}
\usage{
F56(data, varX, varY, OrderCatX=NULL, LabelCatX=NULL, OrderCatY=NULL,
LabelCatY=NULL, shade=TRUE, cex.axis=1, MPLOT=NULL,  ResetPAR=TRUE,
PAR=NULL, XLAB=NULL, YLAB=NULL, COLOR=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{varX}{Qualitative variable X.}
  \item{varY}{Qualitative variable Y.}
  \item{OrderCatX}{It allows to specify a vector with the order in which the categories of the variable \emph{varX} are shown.}
  \item{LabelCatX}{It allows to specify a vector with the names of the categories of the variable \emph{varX}.}
  \item{OrderCatY}{It allows to specify a vector with the order in which the categories of the variable \emph{varY} are shown.}
  \item{LabelCatY}{It allows to specify a vector with the names of the categories of the variable \emph{varY}.}
  \item{shade}{If it is TRUE a numeric vector of at most 5 distinct positive numbers giving the absolute values of the cut points for the residuals.}
  \item{cex.axis}{Size of the labels of the axes.}
  \item{MPLOT}{It accesses the function \link[graphics]{mosaicplot} that allows to modify the mosaic plot.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{COLOR}{Logical or a vector of colors for color shading, used only when shade is FALSE, or NULL (default). By default, grey boxes are drawn. color = TRUE uses a gamma-corrected grey palette. color = FALSE gives white boxes with no shading.}
}
\value{A mosaic plot is obtained.}  
\details{
\strong{FUNCTIONS}

The mosaic plot is performed with the function \link[graphics]{mosaicplot} of the base package graphics. For further details see Guisande & Vammonde (2012).

\strong{EXAMPLES}

Smoking behaviour of men and women who smoke in different work centres.

\strong{Example 1} In the first example, the question is whether there are differences between the group of people with any of the smoking parents and the group that their parents do not smoke, in the proportion of different types of degrees of smoker.

The figure shows the graphical representation of the contingency table. The categories of the variable X are ordered with the argument \emph{OrcerCatX}.

This chart also shows the residuals of the test \eqn{\chi^2}. As there are categories with color, the null hypothesis that the samples are homogeneous is rejected, that is to say, there are significant differences between the group with one of their smoking parents and the group without smoking parents, in the percentage of the different types of smokers. The chart also gives a very important additional information, the categories where the differences are significant and which are contributing to that, as a whole, the test \eqn{\chi^2} is significant. 

The white color categories are not significantly different, while the categories with color are significantly different. In particular, it notes that under the category of non-smoking parents, for both men and women, there is a significantly higher proportion of people who do not smoke (solid line). On the contrary, the number of people who do not smoke is significantly lower in the group of smoking parents (dashed line). Therefore, the fact that the parents do not smoke appears to foster their children not to smoke. However, once a person smokes, the degree to which smoke does not vary depending on whether the parents smoke or not smoke, as it could be observed that in all the categories of smokers, the color of the bars is white.
\tabular{c}{
\figure{F124}{options: width=5.3in}
}
\strong{Example 2} The question is whether there are significant differences among working places in the proportion of males and females. As the color of all categories is white, there are not significant differences.
\tabular{c}{
\figure{F125}{options: width=4.3in}
}
\strong{Example 3} As in the example 2, but as there are not significant differences, a grey palette is added with the argument \emph{COLOR=TRUE}. To use the argument \emph{COLOR}, it must be \emph{shade=FALSE}.
\tabular{c}{
\figure{F126}{options: width=4.3in}
}
}
\references{
Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.
}
\examples{
\dontrun{

#Example1

data(Z20)

F56(data=Z20, varX="Smoker", varY="Parents", OrderCatX=c("1 to 10 cigarettes a day",
"11 to 20 cigarettes a day", "1 to 2 cigarette packets", "More than 2 cigarette packets",
"Non-smoker"),cex.axis=0.8)

#Example 2

data(Z20)

F56(data=Z20, varX="Workplace", varY="Sex")

#Example 3

data(Z20)

F56(data=Z20, varX="Workplace", varY="Sex", shade=FALSE, COLOR=TRUE)
}
}
\keyword{F56}
