\name{F62}
\alias{F62}
\encoding{latin1}
\title{SCATTER PLOTS WITH MARGINAL BEANPLOTS}
\description{It performs a simple scatter plot with or without text labels and a regression model, and marginal beanplots.}
\usage{
F62(data, varY, varX, textlabel=NULL, label=NULL, MAR1=c(5,5,1,1),
MAR2=c(2,5,1,1), MAR3=c(5,1.5,1,1), reg=FALSE, model="Linear", outliers=FALSE,
quant1=0.05, quant2 = 0.95,  ci=TRUE, level=0.95, ResetPAR=FALSE, PAR=NULL,
XLAB=NULL, YLAB=NULL, COLOR="black", COLORR="red", PCH=16, lty=1, ltyci=2,
lwd=2.5, R2.pos="topleft", PLOT=NULL, LEGEND=NULL, AXIS=NULL, MTEXT= NULL,
TEXT=NULL, dec=",", file="Output.txt", BEANPLOT=NULL, COLORb="grey", ll=0.16)
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Quantitative independent variable.}
  \item{MAR1}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the scatter plot.}
  \item{MAR2}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the upper beanplot.}
  \item{MAR3}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the right side beanplot.}
  \item{textlabel}{Variable with the text labels.}
  \item{label}{It allows to specify the characteristics of the text labels with the function \link[graphics]{text}.}
  \item{reg}{If TRUE a regression model is performed.}
  \item{model}{One regression model can be selected: "Linear" , "Log", "S-curve", "Power", "Exp", "Quadratic", "Cubic", "Inverse".  It is not considered the model in those cases in which there is the logarithm that apply to any of the variables, if any value of the variable, which applies the logarithm, is zero or negative. The inverse model is not calculated if any value of the independent variable is zero.}
\item{outliers}{If it is TRUE, the outliers are removed using the selected regression model.}
  \item{quant1}{Quantile of the lower end to the elimination of outliers.}
  \item{quant2}{Quantile of the upper end to the elimination of outliers.}
  \item{ci}{If it is TRUE the confidence interval is depicted, but only for the linear regression model.}
  \item{level}{Tolerance/confidence level.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis in the scatter plot.}
  \item{YLAB}{Legend of the Y axis in the scatter plot.}
  \item{COLOR}{Color of the symbols.}
  \item{COLORR}{Color of the line of the regression model.}
  \item{PCH}{Graphic symbol (see the description of the same argument in the function \link{F1}).}
  \item{lty}{Type of the regression line (see the description of the same argument in the function \link{F1}).}
  \item{ltyci}{Type of the confidence interval line (see the description of the same argument in the function \link{F1}).}
  \item{lwd}{Line width of the regression line.}
  \item{R2.pos}{If it is not NULL, with this argument is possible to specify the position of the \eqn{r^2} of the regression in the scatter plot.}
  \item{PLOT}{It allows to specify the characteristics of the scatter plot with the function \link[graphics]{plot.default}.}
  \item{LEGEND}{It allows to include a legend to the scatter plot.}
  \item{AXIS}{It allows to add axes to the scatter plot.}
  \item{MTEXT}{It allows to add text on the margins of the scatter plot.}
  \item{TEXT}{It allows to add text in any area of the inner part of the scatter plot.}
  \item{dec}{It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{file}{TXT FILE. If the argument \emph{reg=TRUE} a TXT file is saved with the information of the regression.}
  \item{BEANPLOT}{It allows to specify the characteristics of the beanplots with the function \link[beanplot]{beanplot}.}
  \item{COLORb}{A vector of up to four colors can be used in the following order: area of the beans (without the border, use border for that color), the lines inside the bean, the lines outside the bean, and the average line per bean.}
  \item{ll}{The length of the beanline per point found.}
}
\value{A simple scatter plot with or without linear regression and marginal beanplots is obtained. Moreover, a TXT file is saved with the results of the regression model.}  
\details{
\strong{FUNCTIONS}

The scatter plot is performed with the function \link[graphics]{plot.default} of base graphics package and the linear regression with the function \link[stats]{lm} of base stats package.

The function \link[nortest]{lillie.test} of the package nortest (Gross, 2013) is used to perform the test of Normality Kolmogorov-Smirnov with Lilliefors'correction.

The function \link[lmtest]{dwtest} of the package lmtest (Hothorn et al., 2013) is used to analyze the autocorrelation with the test and the Durbin-Watson statistic.

The function \link[lmtest]{bptest} of the package lmtest (Hothorn et al., 2013) is used to perform the Breusch-Pagan test of homoscedasticity.

The beanplots are performed with the function \link[beanplot]{beanplot} of the beanplot package (Kampstra, 2008; Kampstra, 2015).

For further details see the help of the function \link[beanplot]{beanplot} and/or Guisande & Vammonde (2012).

\strong{EXAMPLES}

\strong{Example 1} The data are scores of a Principal Component Analysis (PCA) performed to physicochemical parameters from lakes in Colombia. In this example, text labels are assigned to the points with the argument \emph{textlabel="Lake"}.
\tabular{c}{
\figure{F138}{options: width=3.6in}
}
\strong{Example 2} For the examples, morphometric data of several fish species of Characiforms are used (Guisande et al., 2010). It is shown the relationship between M11 and M13 for all species. The length of the lines inside the beanplot was modified with the argument \emph{ll=0.05}.
\tabular{c}{
\figure{F139}{options: width=3.6in}
}
\strong{Example 3} A linear regression line is added to the example 2 with the argument \emph{reg=TRUE}.
\tabular{c}{
\figure{F140}{options: width=3.9in}
}
For the explanation of the regression model shown in the TXT file, see function \link{F1}.
}
\references{
Durbin, J. & Watson G.S. (1951) Testing for serial correlation in least squares regression. \emph{Biometrika}, \strong{38}, 159-171.

Gross, J. (2013) Tests for Normality. R package version 1.0-2. Available at: \url{https://CRAN.R-project.org/package=nortest}.

Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.

Guisande, C. & Vaamonde, A. (2012) \emph{Grficos estadsticos y mapas con R}. Ediciones Daz de Santos, Madrid, 367 pp.

Hothorn, T. et al., (2013) Testing Linear Regression Models. R package version 0.9-33. Available at: \url{https://CRAN.R-project.org/package=lmtest}.

Kampstra, P (2008). Beanplot: A Boxplot Alternative for Visual Comparison of Distributions. \emph{Journal of Statistical Software, Code Snippets}, 28: 1-9.

Kampstra, P (2015) Visualization via Beanplots (like Boxplot/Stripchart/Violin Plot). R package version 1.2. Available at: \url{https://CRAN.R-project.org/package=beanplot}.
}
\examples{
\dontrun{

#Example 1

data(Z6)

F62(data=Z6, varY="Dimension2", varX="Dimension1", textlabel="Lake",
XLAB="Dimension 1", YLAB="Dimension 2",PLOT = c("xlim= c(-1,1)", "xlab=xlab",
"ylab=ylab", "col=COLOR", "pch=PCH"))

#Example 2

data(Z1)

F62(data=Z1, varY="M13", varX="M11", ll=0.05)

#Example 3

F62(data=Z1, varY="M13", varX="M11", reg=TRUE, ll=0.05)
}
}
\keyword{F62}
