\name{F65}
\alias{F65}
\encoding{latin1}
\title{ROSE DIAGRAMS}
\description{It performs a wind rose diagram, although it may be depicted any other air-quality variable.}
\usage{
F65(data, winds, windd, var=NULL, date=NULL, year, month,
date.format="\%d/\%m/\%Y \%H:\%M", type="default", ws.int=2, statistic="prop.count", 
key.position="right", paddle=TRUE, annotate=TRUE, WROSE=NULL, PROSE=NULL,
COLOR="default", SUB=NULL, dec=",")}
\arguments{
  \item{data}{Data file.}
  \item{winds}{Variable with the wind speed.}
  \item{windd}{Variable with the wind direction.}
  \item{var}{Any air-quality variable.}
  \item{date}{Variable with the date.}
  \item{year}{It is possible to select one or several years in a vector. It is necessary to specify the variable \emph{date}.}
  \item{month}{It is possible to select one or several months in a vector. It is necessary to specify the variable \emph{date}.}
  \item{date.format}{The format of date: "\%d/\%m/\%Y \%H:\%M", "\%d/\%m/\%Y", "\%Y/\%m/\%d \%H:\%M", "\%Y/\%m/\%d", "\%d-\%m-\%Y \%H:\%M", "\%d-\%m-\%Y", "\%Y-\%m-\%d \%H:\%M" or "\%Y-\%m-\%d".}
  \item{type}{It determines how the data are split: "year", "season", "month" "weekday" and so on. It is necessary to specify the variable \emph{date}. It is also possible to choose type as another variable in the data frame. For further details see function \link[openair]{windRose} of the package openair (Carslaw, 2016).}
  \item{ws.int}{The wind speed interval.}
  \item{statistic}{The statistic to be applied to each data bin in the plot: "prop.count", "prop.mean" and "abs.count".}
  \item{key.position}{Location where the scale key is to plotted: "top", "right", "bottom" and "left".}
  \item{paddle}{If TRUE plots rose using 'paddle' style spokes. If FALSE plots rose using 'wedge' style spokes.}
  \item{annotate}{If TRUE then the percentage calm and mean values are printed in each panel together with a description of the statistic below the plot.}
  \item{WROSE}{It accesses the function \link[openair]{windRose} that allows to modify many different aspects of the wind rose diagram.}
  \item{PROSE}{It accesses the function \link[openair]{pollutionRose} that allows to modify many different aspects of the pollution rose diagram.}
  \item{COLOR}{Colours to be used for plotting. Options include "default", "increment", "heat", "jet", "hue" and user defined.}
  \item{SUB}{Legend of the subtitle in the rose diagram.}
  \item{dec}{It defines if the comma "," is used as decimal separator or the dot ".".}
}
\value{A wind rose diagrams are obtained.}  
\details{
\strong{FUNCTIONS}

The wind rose and pollution rose diagrams are performed with the function \link[openair]{windRose} of the package openair (Carslaw & Ropkins, 2012; 2016).

\strong{EXAMPLES}

For the examples, hourly data of air pollutants, wind speed and wind direction in Santiago de Compostela (Spain) from 1/11/2015 to 31/12/2015 are used. The data were obtained from \url{http://www.meteogalicia.es/web/index.action}.

\strong{Example 1}. Mean values of nitrogen dioxide for the all period.
\tabular{c}{
\figure{F145}{options: width=4.6in}
}
\strong{Example 2}. Monthly means of particulate matter 10 micrometers or less in diameter. The language of the months is according to regional language settings of the control panel.
\tabular{c}{
\figure{F146}{options: width=5.5in}
}
\strong{Example 3}. Weekly means of sulfur dioxide in grey scale.
\tabular{c}{
\figure{F147}{options: width=3.7in}
}
\strong{Example 4.} Mean values of wind speed and direction in November. The argument \emph{var=NULL}. 
\tabular{c}{
\figure{F148}{options: width=3.7in}
}
}
\references{
Carslaw, D. & Ropkins, K. (2012) openair - An R package for air quality data analysis. \emph{Environmental Modelling & Software}, 27-28: 52-61. doi \url{10.1016/j.envsoft.2011.09.008}.
Carslaw, D. & Ropkins, K. (2016) Tools for the Analysis of Air Pollution Data. R package version 1.6.7. Available at: \url{https://CRAN.R-project.org/package=openair}.
}
\examples{
\dontrun{

#Example 1

data(Z22)

F65(data=Z22, winds="Ws", windd="Wd", var="NO2", paddle=FALSE)

#Example 2

F65(data=Z22, winds="Ws", windd="Wd", var="PM10", date="date", type="month", paddle=FALSE)

#Example 3

F65(data=Z22, winds="Ws", windd="Wd", var="SO2", date="date", type="weekday",
paddle=FALSE, COLOR="greyscale")

#Example 4

F65(data=Z22, winds="Ws", windd="Wd", date="date", month=11)
}
}
\keyword{F65}
