\name{F68}
\alias{F68}
\encoding{latin1}
\title{WALTER-LIETH DIAGRAM}
\description{It performs a Walter-Lieth diagram.}
\usage{
F68(data, date, Tmin, Tmax, Prec, year, date.format="\%d/\%m/\%Y", est="",
alt=NA, per="", mlab="RLS", pcol="#005ac8", tcol="#e81800", pfcol="#79e6e8",
sfcol="#09a0d1", shem=FALSE, p3line=FALSE, mar=c(4,4,5,4), ResetPAR=TRUE, PAR=NULL,
file="Output.csv", na="NA", dec=",", row.names=TRUE)
}
\arguments{
  \item{data}{Data file. There are two options: 1) An 4x12 matrix, one column for each month, without NAs, where first row is monthly precipitation (mm), second row is monthly average maximum daily temperature (degrees C), third row is monthly average minimum daily temperature (degrees C) and forth row is monthly absolute minimum daily temperature (degrees C); 2) a data frame with the variables date, minimum temperature, maximum temperature and precipitation.}
  \item{date}{Variable with the date.}
  \item{Tmin}{Variable with the daily mean minimum temperature.}
  \item{Tmax}{Variable with the daily mean maximum temperature.}
  \item{Prec}{Variable with the daily total precipitation.}
  \item{year}{It is possible to select one or several years in a vector.}
  \item{date.format}{The format of date: "\%d/\%m/\%Y \%H:\%M", "\%d/\%m/\%Y", "\%Y/\%m/\%d \%H:\%M", "\%Y/\%m/\%d", "\%d-\%m-\%Y \%H:\%M", "\%d-\%m-\%Y", "\%Y-\%m-\%d \%H:\%M" or "\%Y-\%m-\%d"}
\item{est}{Name of the weather station.}
  \item{alt}{Altitude of the weather station.}
  \item{per}{Period for which the averages have been computed.}
  \item{mlab}{If it is "RLS" the names of the months are those defined in the regional language settings of the computer. If it is "number" the number of the months are used.}
  \item{pcol}{Color for precipitation.}
  \item{tcol}{Color for temperature.}
  \item{pfcol}{Fill color for probable frosts.}
  \item{sfcol}{Fill color for sure frosts.}
  \item{shem}{Set to TRUE for southern hemisphere stations.}
  \item{p3line}{Set to TRUE to draw a suplementary precipitation line referenced to three times the temperature.}
  \item{mar}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the figure.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{file}{Name of the CSV file with the estimation for each month of the monthly precipitation (mm), monthly average maximum daily temperature (degrees C), monthly average minimum daily temperature (degrees C) and monthly absolute minimum daily temperature (degrees C), if the data is not a 4x12 matrix.}
  \item{na}{CSV FILE. Text that is used in the cells without data.}
  \item{dec}{CSV FILE. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILE. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{A Walter- Lieth diagram is depicted and if the data is not a 4x12 matrix, a CSV is saved with the monthly precipitation (mm), monthly average maximum daily temperature (degrees C), monthly average minimum daily temperature (degrees C) and monthly absolute minimum daily temperature (degrees C), one column for each month.}  
\details{
\strong{FUNCTIONS}

The Walter-Lieth diagram is performed with the function climatol (Guijarro, 2103).

\strong{EXAMPLES}

The data are maximum and minimum temperatures and precipitation in 1990 and 2000 in three cities in Spain: Huelva, Palma de Mallorca and Vigo (\url{http://www.aemet.es/es/portada}).

\strong{Example 1}. An example using the format: date, minimum temperature, maximum temperature and precipitation. The plot shows the values in Vigo (Spain) in the year 2000.
\tabular{c}{
\figure{F155}{options: width=3.6in}
}
\strong{Example 2}. An example with the data format of an 4x12 matrix. The plot shows the values in Huelva (Spain) in the years 1990 and 2000.
\tabular{c}{
\figure{F156}{options: width=3.8in}
}
}
\references{
Guijarro, J.A. (2013) An R contributed package for homogenization of climatological series (and functions for drawing wind-rose and Walter&Lieth diagrams). R package version 2.2. Available at: \url{https://cran.r-project.org/src/contrib/Archive/climatol/}.
}
\examples{
\dontrun{

#Example 1

data(Z23)

data<-subset(Z23,(City == "Vigo"))

F68(data=data, date="date", Tmin="T.min", Tmax="T.max", Prec="Precipitation",
year=2000, est="Vigo (Spain)", alt=261, per="2000")

#Example 2

data(Z24)

F68(data=Z24, est="Huelva (Spain)", alt=12, per="1990 and 2000")
}
}
\keyword{F68}
