\name{F71}
\alias{F71}
\encoding{latin1}
\title{3D LEVEL PLOT}
\description{A 3D level plot is depicted.}
\usage{
F71(data, X, Y,  Z, SURFACE=NULL, axes=FALSE, AXES=NULL,
MTEXT=NULL, TITLE=NULL, XLAB="", YLAB="", ZLAB="", MAIN=NULL,
SUB=NULL, LINE=NA, COL=NULL, COLT="black", FONT=2, CEX=1.5)
}
\arguments{
  \item{data}{Data file.}
  \item{X}{Variable X.}
  \item{Y}{Variable Y.}
  \item{Z}{Variable Z.}
  \item{SURFACE}{It accesses the function \link[rgl]{rgl.surface} that allows to modify many different aspects of the 3d plot.}
  \item{axes}{If TRUE the axes are displayed.}
  \item{AXES}{It accesses the function \link[rgl]{axes3d} that allows to modify the axes.}
  \item{MTEXT}{It accesses the function \link[rgl]{mtext3d} that allows to add text outside the plot.}
  \item{TITLE}{It accesses the function \link[rgl]{title3d} that allows to modify the text the plot.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{ZLAB}{Legend of the Z axis.}
  \item{MAIN}{Main title of the 3d plot.}
  \item{SUB}{Subtitle of the 3d plot.}
  \item{LINE}{The line of the plot margin to draw the label on.}
  \item{COL}{Gradient color.}
  \item{COLT}{Color of the text.}
  \item{FONT}{Font of the text.}
  \item{CEX}{Size of the text.}
}
\value{A 3D surface plot is depicted.}  
\details{
\strong{FUNCTIONS}

The plot is performed with the functions \link[rgl]{mtext3d}, , \link[rgl]{axes3d}, , \link[rgl]{open3d}, \link[rgl]{rgl.surface} and \link[rgl]{title3d} of the package rgl (Adler et al., 2017).

\strong{EXAMPLES}

Altitude in the Himalayan region, with the altitude (variable Z) in a matrix format.
\tabular{c}{
\figure{F162}{options: width=4in}
}
}
\references{
Adler, D., Murdoch, D. et al. (2017) 3D Visualization Using OpenGL. R package version 0.98.1. Available at: \url{https://CRAN.R-project.org/package=rgl}.
}
\examples{
\dontrun{

#Including the variable Z as a matrix

data(Z10)
m<-as.matrix(Z10[,c(-1,-2)])
F71(data=Z10,  X="Longitude", Y="Latitude",  Z=m)

#Including only a matrix

data(volcano)
F71(data=volcano)

#Identifying the variable Z

data(Z10)

F71(data=Z10, X="Latitude", Y="Longitude", Z=c("Z1","Z2","Z3", "Z4","Z5","Z6",
"Z7","Z8","Z9","Z10","Z11","Z12","Z13","Z14","Z15","Z16","Z17","Z18","Z19","Z20",
"Z21","Z22","Z23","Z24","Z25","Z26","Z27","Z28","Z29","Z30","Z31","Z32","Z33",
"Z34","Z35","Z36","Z37","Z38","Z39","Z40","Z41","Z42","Z43","Z44","Z45","Z46",
"Z47","Z48","Z49","Z50","Z51","Z52","Z53","Z54","Z55","Z56","Z57","Z58","Z59",
"Z60","Z61","Z62","Z63","Z64","Z65","Z66","Z67","Z68","Z69","Z70","Z71","Z72",
"Z73","Z74","Z75","Z76","Z77","Z78","Z79","Z80","Z81","Z82","Z83","Z84","Z85",
"Z86","Z87","Z88","Z89","Z90","Z91","Z92","Z93","Z94","Z95","Z96","Z97","Z98",
"Z99","Z100","Z101","Z102","Z103","Z104","Z105","Z106","Z107","Z108","Z109",
"Z110","Z111","Z112","Z113","Z114","Z115","Z116","Z117","Z118","Z119","Z120",
"Z121","Z122","Z123","Z124","Z125","Z126","Z127","Z128","Z129","Z130","Z131",
"Z132","Z133","Z134","Z135","Z136","Z137","Z138","Z139","Z140","Z141","Z142",
"Z143","Z144","Z145","Z146","Z147","Z148","Z149","Z150","Z151","Z152","Z153",
"Z154","Z155","Z156","Z157","Z158","Z159","Z160","Z161","Z162","Z163","Z164",
"Z165","Z166","Z167","Z168","Z169","Z170","Z171","Z172","Z173","Z174","Z175",
"Z176","Z177","Z178","Z179","Z180","Z181","Z182","Z183","Z184","Z185","Z186",
"Z187","Z188","Z189","Z190","Z191","Z192","Z193","Z194","Z195","Z196","Z197",
"Z198","Z199","Z200","Z201","Z202","Z203","Z204","Z205","Z206","Z207","Z208",
"Z209","Z210","Z211","Z212","Z213","Z214","Z215","Z216","Z217","Z218","Z219",
"Z220","Z221","Z222","Z223","Z224","Z225","Z226","Z227","Z228","Z229","Z230",
"Z231","Z232","Z233","Z234","Z235","Z236","Z237","Z238","Z239","Z240","Z241",
"Z242","Z243","Z244","Z245","Z246","Z247","Z248","Z249","Z250","Z251","Z252",
"Z253","Z254","Z255","Z256","Z257","Z258","Z259","Z260","Z261","Z262","Z263",
"Z264","Z265","Z266","Z267","Z268","Z269","Z270","Z271","Z272","Z273","Z274",
"Z275","Z276","Z277","Z278","Z279","Z280","Z281","Z282","Z283","Z284","Z285",
"Z286","Z287","Z288","Z289","Z290","Z291","Z292","Z293","Z294","Z295","Z296",
"Z297","Z298","Z299","Z300","Z301","Z302","Z303","Z304","Z305","Z306","Z307",
"Z308","Z309","Z310","Z311","Z312","Z313","Z314","Z315","Z316","Z317","Z318",
"Z319","Z320","Z321","Z322","Z323","Z324","Z325","Z326","Z327","Z328","Z329",
"Z330","Z331","Z332","Z333","Z334","Z335","Z336","Z337","Z338","Z339","Z340",
"Z341","Z342","Z343","Z344","Z345","Z346","Z347","Z348","Z349","Z350","Z351",
"Z352","Z353","Z354","Z355","Z356","Z357","Z358","Z359","Z360","Z361","Z362",
"Z363","Z364","Z365","Z366","Z367","Z368","Z369","Z370","Z371","Z372","Z373",
"Z374","Z375","Z376","Z377","Z378","Z379","Z380","Z381","Z382","Z383","Z384",
"Z385","Z386","Z387","Z388","Z389","Z390","Z391","Z392","Z393","Z394","Z395",
"Z396","Z397","Z398","Z399","Z400","Z401","Z402","Z403","Z404","Z405","Z406",
"Z407","Z408","Z409","Z410","Z411","Z412","Z413","Z414","Z415","Z416","Z417",
"Z418","Z419","Z420","Z421","Z422","Z423","Z424","Z425","Z426","Z427","Z428",
"Z429","Z430","Z431","Z432","Z433","Z434","Z435","Z436","Z437","Z438","Z439",
"Z440","Z441","Z442","Z443","Z444","Z445","Z446","Z447","Z448","Z449","Z450",
"Z451","Z452","Z453","Z454","Z455","Z456","Z457","Z458","Z459","Z460","Z461",
"Z462","Z463","Z464","Z465","Z466","Z467","Z468","Z469","Z470","Z471","Z472",
"Z473","Z474","Z475","Z476","Z477","Z478","Z479","Z480","Z481"))

}
}
\keyword{F71}
