\name{F76}
\alias{F76}
\title{SHAPES OF RIVER BASINS AND ADMINISTRATE AREAS OF RWIZARD}
\description{Enables mapping of shapes and also, shapes of administrative areas and river basins available into RWizard.}
\usage{
F76(Area="World", minLon, maxLon, minLat, maxLat, colbg="#FFFFFF",
colcon="#C8C8C8", colf="black", pro = TRUE, boxf = "plot", inc = 0.005,
exclude=NULL, colexc=NULL, colfexc="black", axes=TRUE, asp, lab= NULL,
xlab="Longitude", ylab="Latitude", main=NULL, cex.main=1.6, cex.lab=1.4,
cex.axis=1.2, family="sans", font.main=2, font.lab=1, font.axis=1,
jpg=FALSE, filejpg="Map.jpg")
}
\arguments{
  \item{Area}{A character with the name of the administrative area or a vector with several administrative areas (see details).}
  \item{minLon, maxLon}{Optionally it is possible to define the minimum and maximum longitude (see details).}
  \item{minLat, maxLat}{Optionally it is possible to define the minimum and maximum latitude (see details).}
  \item{colbg}{Background color of the map (in some cases is the sea).}
  \item{colcon}{Background color of the administrative areas.}
  \item{colf}{Color of administrative areas border.}
  \item{pro}{If it is TRUE an automatic calculation is made in order to correct the aspect ratio y/x along latitude.}
  \item{boxf}{Draws a box around the current plot: "plot", "figure", "inner", "outer" or "n" (without box).}
  \item{inc}{Add some room on the margins of the map and, therefore, the limits x and y are not exactly the limits of the selected areas.}
  \item{exclude}{A character with the name of the administrative area or a vector with several administrative areas that may be plotted with a different color in the map.}
  \item{colexc}{Background color of areas selected in the argument exclude.}
  \item{colfexc}{Color of borders of the areas selected in the argument exclude.}
  \item{axes}{If FALSE does not draw the axes.}
  \item{asp}{The y/x aspect ratio.}
  \item{lab}{A numerical vector of the form c(x, y) which modifies the default way that axes are annotated. The values of x and y give the (approximate) number of tickmarks on the x and y axes.}
  \item{xlab}{A title for the x axis.}
  \item{ylab}{A title for the y axis.}
  \item{main}{An overall title for the plot.}
  \item{cex.main}{The magnification to be used for main titles relative to the current setting of cex.}
  \item{cex.lab}{The magnification to be used for x and y labels relative to the current setting of cex.}
  \item{cex.axis}{The magnification to be used for axis annotation relative to the current setting of cex.}
  \item{family}{The name of a font family for drawing text.}
  \item{font.main}{The font to be used for plot main titles.}
  \item{font.lab}{The font to be used for x and y labels.}
  \item{font.axis}{The font to be used for axis annotation.}
  \item{jpg}{If TRUE the plots are exported to jpg files instead of using the windows device.}
  \item{filejpg}{Name of the jpg file.}
}
\details{

\strong{FUNCTIONS}

The function \link[graphics]{image} and the function \link[plotrix]{color.legend} of the package plotrix (Lemon et al., 2014) are used for building the map.

\strong{EXAMPLES}

\emph{Example 1}

If the argument \emph{Area = "World"} (default) the entire world is plotted.
\tabular{c}{
\figure{F170}{options: width=4.5in}
}

\emph{Example 2}

Clicking on the icon world, as it is shown in the following screenshot (red arrow), would display a menu with all countries and their regions.
\tabular{c}{
\figure{F171}{options: width=5in}
}
It is possible to select one or several countries and/or regions and the selected administrative areas would be only shown in the map. For instance the following maps show Philippines, Haiti and Dominican Republic.
\tabular{c}{
\figure{F172}{options: width=2.5in}\cr
\figure{F173}{options: width=3.2in}\
}
\emph{Example 3}

It is also possible to change the background color.
\tabular{c}{
\figure{F174}{options: width=2.1in}
}
\emph{Example 4}

If the arguments \emph{minLon}, \emph{maxLon}, \emph{minLat} and \emph{maxLat} are not specified, they are calculated automatically based on the countries and/or regions selected. The latitude and longitude of the map may be delimited, by just specifying the arguments \emph{minLon}, \emph{maxLon}, \emph{minLat} and \emph{maxLat}.
\tabular{c}{
\figure{F175}{options: width=1.7in}
}
\emph{Example 5}

It is also possible to give different colors to the countries, as shown in the following map.
\tabular{c}{
\figure{F176}{options: width=5in}
}

}
\value{Maps are depicted.}
\references{
Lemon, J., Bolker, B., Oom, S., Klein, E., Rowlingson, B., Wickham, H., Tyagi, A., Eterradossi, O., Grothendieck, G., Toews, M., Kane, J., Turner, R., Witthoft, C., Stander, J., Petzoldt, T., Duursma, R., Biancotto, E., Levy, O., Dutang, C., Solymos, P., Engelmann, R., Hecker, M., Steinbeck, F., Borchers, H., Singmann, H., Toal, T. & Ogle, D. (2014). Various plotting functions. R package version 3.5-7. Available at: https://CRAN.R-project.org/package=plotrix.
}
\examples{
\dontrun{

#Example 1. The world
@_Build_AdWorld_
F76()

#Example 2. Map of Philippines
@_Build_AdWorld_
F76(Area = "Philippines", main="Philippines")

#Two countries
@_Build_AdWorld_ 
F76(Area=c("Dominican Republic","Haiti"), main="Haiti and Dominican Republic")

#Example 3. Changes of background color
@_Build_AdWorld_
F76(Area = c("Bahamas") , colbg = "#7FFFD4FF" , colcon = "#CAFF70FF", main="Bahamas")

#Example 4. Selection of latitudes and longitudes in the Bahamas
@_Build_AdWorld_
F76(Area = c("Bahamas") , minLon = -78.1 , maxLon = -77.4 , minLat = 23.6 ,
maxLat = 24.5 , colbg = "#7FFFD4FF" , colcon = "#CAFF70FF", main="Bahamas")

#Example 5. Countries with different colors
@_Build_AdWorld_
F76(minLon=-100, maxLon=-60, minLat=5, maxLat=30, main="Central America",
cex.main=1.4, colcon="#FFFFFF",exclude = c("Anguilla", "Antigua and Barbuda",
"Aruba", "Bahamas", "Barbados", "Central America>Belize",
"Bonaire, Sint Eustatius and Saba", "British Virgin Islands", "Cayman Islands",
"Clipperton Island", "Costa Rica", "Cuba", "Curaao", "Dominica", "Dominican Republic",
"El Salvador", "Grenada", "Guadeloupe", "Central America>Guatemala",
"Haiti", "Honduras", "Jamaica", "Martinique", "Montserrat", "Nicaragua",
"Panama", "Puerto Rico", "Saint Barthlemy", "Saint Kitts and Nevis",
"Saint Martin", "Saint Vincent and the Grenadines", "Santa Lucia",
"Sint Maarten", "Turks and Caicos Islands", "Virgin Islands") , colexc = "#F0E68CFF")
}
}
\keyword{F76}
