\name{F81}
\alias{F81}
\encoding{latin1}
\title{JOYPLOT FOR ONE VARIABLE WITH DIFFERENT GROUPS}
\description{It performs a joyplot of one variable with different groups and the overlap of the area under de curve among groups is also estimated.}
\usage{
F81(data, var, group, kernel="gaussian", PLOT=NULL, overlap=TRUE,
lty=1, lwd=2.5, ResetPAR=TRUE, PAR=NULL, XLAB=NULL, XLIM=NULL, YLIM=NULL,
COLOR=NULL, COLORB=NULL, AXIS=NULL, CEX=1.2, file="Output.csv",
na="NA", dec=",", row.names=FALSE)
}
\arguments{
  \item{data}{Data file.}
  \item{var}{Variables.}
  \item{group}{Variable with the categories to be grouped.}
  \item{kernel}{A character string giving the smoothing kernel to be used. This must be one of "gaussian", "rectangular", "triangular", "epanechnikov", "biweight", "cosine" or "optcosine". For further details about the estimation of the density curve see the details section of the function \link[stats]{density} of base stats package.}
  \item{PLOT}{It allows to specify the characteristics of the function \link[graphics]{plot.default}.}
  \item{overlap}{If it is TRUE the overlap of the area under the curve among variables is estimated. For further details about the estimation of the area under the curve see the details section of the function \link[kulife]{auc} of the package kulife (Ekstrom et al., 2015).}
  \item{lty}{Type of line of the density curve for each variable. If it is a vector, it must be as many as different variables. See the description of the same argument in the function \link{F1}.}
  \item{lwd}{Line width relative to the default (default=1), so 2 is twice as wide.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis.}
  \item{XLIM}{Vector with the limits of the X axis.}
  \item{YLIM}{Vector with the limits of the Y axis.}
  \item{COLOR}{Color of the density curves. It must be as many as different groups.}
  \item{COLORB}{Color of the lines. It must be as many as different groups.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{CEX}{Size of the labels of each group and of the legend of X axis.}
  \item{file}{CSV FILE. File name with the overlap of the area under the curve among groups.}
  \item{na}{CSV FILE. Text that is used in the cells without data.}
  \item{dec}{CSV FILE. It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{row.names}{CSV FILE. Logical value that defines if identifiers are put in rows or a vector with a text for each of the rows.}
}
\value{A joyplot for one variable with different groups and a CSV file with the overlap of the area under de curve among groups are obtained.}  
\details{
\strong{FUNCTIONS}

The plot is performed with the function \link[graphics]{plot.default} of base graphics package. The density curve is estimated with the function \link[stats]{density} of base stats package. The area under the curve is estimated with the function \link[kulife]{auc} of the package kulife (Ekstrom et al., 2015).

\strong{EXAMPLES}

For the example, morphometric data of three families of freshwater fishes, as the distance from the origin of the dorsal fin to the origin of the anal fin (M13), the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010).

A joyplot plot is depicted for the variable M6 for each family.
\tabular{c}{
\figure{F183}{options: width=3in}
}
The overlap of the area under the curve among families is obtained. The 87.87\% of the area of the family Cichlidae overlaps with the family Sparidae, the 9.74\% of the area of the family Cichlidae overlaps with the family Characidae, 87.69\% of the area of the family Sparidae overlaps with the family Cichlidae, etc.
}
\references{
Ekstrom, C., Skovgaard, Ib M. & Martinussen, T.(2015) Datasets and functions from the (now non-existing). R package version 0.1-14. Available at: \url{https://CRAN.R-project.org/package=kulife}.

Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.
}
\examples{
\dontrun{

data(Z8)

F81(data=Z8, var="M6", group="Family")
}
}
\keyword{F81}
