\name{F82}
\alias{F82}
\encoding{latin1}
\title{MULTIPLE SCATTER PLOTS WITH MARGINAL HISTROGRAMS}
\description{It performs a multiple scatter plot with or without text labels, regression model and marginal histograms.}
\usage{
F82(data, varY, varX, group, textlabel=NULL, label=NULL, MAR1=c(5,5,1,1),
MAR2=c(1,5,1,1), MAR3=c(5,1,1,1), reg=FALSE, model="Linear", outliers=FALSE,
quant1=0.05, quant2 = 0.95, ResetPAR=FALSE, PAR=NULL, XLAB=NULL, YLAB=NULL,
COLOR=NULL, COLORR=NULL, PCH=NULL, CEX=1,  lty=NULL, lwd=2.5, PLOT=NULL,
LEGEND=NULL,  AXIS=NULL, MTEXT= NULL, TEXT=NULL, HIST=NULL, HISTh=NULL,
breaks=20, COLORl=NULL, COLORb=NULL, dec=",", file="Output.txt")
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Quantitative independent variable.}
  \item{group}{Variable with the categories to be grouped.}
  \item{textlabel}{Optionally, variable with the text labels.}
  \item{label}{It allows to specify the characteristics of the text labels with the function \link[graphics]{text}.}
  \item{MAR1}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the scatter plot.}
  \item{MAR2}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the upper histogram.}
  \item{MAR3}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the right side histogram.}
  \item{reg}{If TRUE a regression model is performed.}
  \item{model}{One regression model can be selected: "Linear" , "Log", "S-curve", "Power", "Exp", "Quadratic", "Cubic", "Inverse".  It is not considered the model in those cases in which there is the logarithm that apply to any of the variables, if any value of the variable, which applies the logarithm, is zero or negative. The inverse model is not calculated if any value of the independent variable is zero.}
\item{outliers}{If it is TRUE, the outliers are removed using the selected regression model.}
  \item{quant1}{Quantile of the lower end to the elimination of outliers.}
  \item{quant2}{Quantile of the upper end to the elimination of outliers.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y axis.}
  \item{COLOR}{Color of the symbols. It must be as many as different categories of the variable \emph{group}.}
  \item{COLORR}{Color of the line of the regression model. It must be as many as different categories of the variable \emph{group}.}
  \item{PCH}{Graphic symbol (see the description of the same argument in the function \link{F1}). It must be as many as different categories of the variable \emph{group}.}
  \item{CEX}{Size of the symbols.}
  \item{lty}{Type of the regression line (see the description of the same argument in the function \link{F1}).}
  \item{lwd}{Line width of the regression line relative to the default (default=1), so 2 is twice as wide.}
  \item{PLOT}{It allows to specify the characteristics of the function \link[graphics]{plot.default}.}
  \item{LEGEND}{It allows to modify the legend of the graph.}
  \item{AXIS}{It allows to add axes to the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
\item{HIST}{It allows to specify the characteristics of the upper histogram with the function \link[graphics]{hist}.}
  \item{HISTh}{It allows to specify the characteristics of the right side histogram with the function \link[graphics]{barplot}.}
  \item{breaks}{Number of intervals.}
  \item{COLORl}{Color of the borders. It must be as many as different variables.}
  \item{COLORb}{Color of ther bars. It must be as many as different variables.}
  \item{dec}{It defines if the comma "," is used as decimal separator or the dot ".".}
  \item{file}{TXT FILE. If the argument \emph{reg=TRUE} a TXT file is saved with the information of the regression.}
}
\value{A multiple scatter plot with or without linear regression and marginal histrograms is obtained. Moreover, a TXT file is saved with the results of the regression model.}  
\details{

\strong{FUNCTIONS}

The scatter plot is performed with the function \link[graphics]{plot.default} of base graphics package and the linear regression with the function \link[stats]{lm} of base stats package. The function \link[nortest]{lillie.test} of the package nortest (Gross, 2013) is used to perform the test of Normality Kolmogorov-Smirnov with Lilliefors'correction, the function \link[lmtest]{dwtest} of the package lmtest (Hothorn et al., 2013) to analyze the autocorrelation with the test and the Durbin-Watson statistic function \link[lmtest]{bptest} of the package lmtest (Hothorn et al., 2013) to perform the Breusch-Pagan test of homoscedasticity. The histograms are performed with the functions \link[graphics]{hist} and \link[graphics]{barplot} of base graphics package.

\strong{EXAMPLES}

\strong{Example 1} The data are scores of a Principal Component Analysis (PCA) performed to physicochemical parameters from lakes in Colombia. In this example, text labels are assigned to the points with the argument \emph{textlabel="Lake"}, and the different regions are identified with the argument \emph{group="Region"}.
\tabular{c}{
\figure{F184}{options: width=3.2in}
}
\strong{Example 2} For the examples, morphometric data of several fish species of Characiforms, as the distance from the origin of the dorsal fin to the origin of the anal fin (M13), the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010). It is shown the relationship between M12 and M13 for each genera.
\tabular{c}{
\figure{F185}{options: width=3.3in}
}
\strong{Example 3} A linear regression line is added to the example 2 with the argument \emph{reg=TRUE}.
\tabular{c}{
\figure{F186}{options: width=3.3in}
}
In the TXT file that generates the function, the regression model of each genera is shown. For the explanation of the regression models, normality, autocorrelation and homoscedasticity see the \emph{details} section of the function \link{F1}.
}
\references{
Durbin, J. & Watson G.S. (1951) Testing for serial correlation in least squares regression. \emph{Biometrika}, \strong{38}, 159-171.

Gross, J. (2013) Tests for Normality. R package version 1.0-2. Available at: \url{https://CRAN.R-project.org/package=nortest}.

Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.

Hothorn, T. et al., (2013) Testing Linear Regression Models. R package version 0.9-33. Available at: \url{https://CRAN.R-project.org/package=lmtest}.
}
\examples{
\dontrun{

#Example 1

data(Z6)

F82(data=Z6 , varY="Dimension2", varX="Dimension1", group="Region",
textlabel="Lake", XLAB="Dimension 1", YLAB="Dimension 2", PLOT=c("xlim=c(-1,1)",
"ylim=c(-0.5,1.2),", "xlab=xlab", "ylab=ylab", "col=COLOR", "pch=PCH"))

#Example 2

data(Z8)

F82(data=Z8, varY="M13", varX="M12", group="Family", LEGEND = c("x='bottomright'",
"legend=dati", "pch=PCH", "col=COLOR" , "lty=lty" , "bty='n'"))

#Example 3

data(Z8)

F82(data=Z8, varY="M13", varX="M11", group="Family", reg=TRUE)
}
}
\keyword{F82}
