\name{F85}
\alias{F85}
\encoding{latin1}
\title{ADDITIONAL AXES IN LINE CHARTS AND SCATTER PLOTS FOR VARIABLE X QUALITATIVE}
\description{It is possible to add up to 3 additional axes to line charts and scatterplots with or without text labels, and a regression model.}
\usage{
F85(data, FactorX, varY, varY1=NULL, varY2=NULL, varY3=NULL, method="mean",
dev="sd", type=NULL, MAR1=c(5,5,3,4), MAR2=c(5,5,3,8), MAR3=c(5,5,3,12),
ResetPAR=TRUE, PAR=NULL, order=NULL, OrderCat=NULL, LabelCat=NULL,
XLAB=NULL, YLAB=NULL, YLAB1=NULL, YLAB2=NULL,YLAB3=NULL, XLIM=NULL, YLIM=NULL,
YLIM1=NULL, YLIM2=NULL, YLIM3=NULL, CEX=1.4, FONTLAB=2, CEXLAB=1.5, COLOR=NULL,
COLORI="black", PCH=NULL, ltyL=NULL, lwdL=1, LEGEND=NULL, MTEXT= NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{FactorX}{Qualitative independent variable.}
  \item{varY}{Dependent variable.}
  \item{varY1}{First additional variable.}
  \item{varY2}{Second additional variable.}
  \item{varY3}{Third additional variable.}
  \item{method}{If it is not NULL, the average of each category of the independent variable \emph{FactorX} is estimated with the "mean" or the "median".}
  \item{dev}{If the argument \emph{method} is not NULL, the error bars may be estimated using the standard deviation ("sd") or the standard error ("se").}
  \item{type}{Character string giving the type of plot desired. It must be as many as the number of variables Y. The following values are possible: "p" for points, "l" for lines, "b" for both points and lines (default), "c" for empty points joined by lines, "o" for overplotted points and lines, "s" and "S" for stair steps and "h" for histogram-like vertical lines. Finally, "n" does not produce any points or lines.}
  \item{MAR1}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the scatter plot when adding varY1.}
  \item{MAR2}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the scatter plot when adding varY1 and varY2.}
  \item{MAR3}{A numeric vector with the format c(down, left, up, right) that defines the lines of the margins of the scatter plot when adding varY1, varY2 and varY3.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{order}{If it is NULL the categories are ordered as found in the variable \emph{FactorX}, if it is "increasing" are ordered from lesser to greater median or mean according to the method selected in the argument \emph{method}, if it is "decreasing" are ordered from greater to lesser median or mean, if it is "alhaAZ" are ordered from A to Z and if it is "alphaZA" from Z to A.} 
  \item{OrderCat}{It allows to specify a vector with the order in which the categories are shown. If this argument is specified, the argument \emph{order} is not taken into account.}
  \item{LabelCat}{It allows to specify a vector with the names of the categories.}
  \item{XLAB}{Legend of the X axis.}
  \item{YLAB}{Legend of the Y ax1s.}
  \item{YLAB1}{Legend of the Y1 ax1s.}
  \item{YLAB2}{Legend of the Y2 ax1s.}
  \item{YLAB3}{Legend of the Y3 ax1s.}
  \item{XLIM}{Limits of X axis.}
  \item{YLIM}{Limits of Y axis.}
  \item{YLIM1}{Limits of Y1 axis.}
  \item{YLIM2}{Limits of Y2 axis.}
  \item{YLIM3}{Limits of Y3 axis.}
  \item{CEX}{Size of the symbols.}
  \item{FONTLAB}{Family font of the legends.}
  \item{CEXLAB}{Size of the legends.}
  \item{COLOR}{Color of the symbols. It must be as many as the number of variables Y.}
  \item{COLORI}{Color of the error bars.}
  \item{PCH}{Graphic symbol (see the description of the same argument in the function \link{F1}). It must be as many as the number of variables Y.}
  \item{ltyL}{Type of the line chart (see figure of the argument \emph{lty} in the function \link{F1}). It must be as many as the number of variables Y.}
  \item{lwdL}{Line width of the chart relative to the default (default=1), so 2 is twice as wide.}
  \item{LEGEND}{It allows to modify the legend of the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
}
\value{Line charts and scatterplot with or without linear regression with additional axes are obtained.}  
\details{
\strong{FUNCTIONS}

The plot is performed with the functions \link[graphics]{boxplot}, \link[graphics]{points} and \link[graphics]{arrows} of base graphics package.

\strong{EXAMPLE}

For the examples, morphometric data of freshwater fishes, as the distance from the origin of the dorsal fin to the origin of the anal fin (M13), the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010). The next figure shows the mean values and standard deviation of several morphometric variables for each genus.
\tabular{c}{
\figure{F193}{options: width=5.5in}
}
}
\references{
Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.
}
\examples{
\dontrun{

data(Z1)

F85(data=Z1, FactorX="Genus", varY="M2", varY1="M6", varY2="M12", varY3="M24")
}
}
\keyword{F85}
