\name{F86}
\alias{F86}
\encoding{latin1}
\title{ZOOM PLOT}
\description{This function makes a zoom in a scatterplot.}
\usage{
F86(data, varY, varX, rylim, rxlim, ResetPAR=TRUE, PAR=NULL, XLAB=NULL, YLAB=NULL,
XLIM=NULL, YLIM=NULL, MAIN=NULL, titlepos=NA, COLOR="tomato", PCH=16, ZOOM=NULL,
MTEXT=NULL, TEXT=NULL)
}
\arguments{
  \item{data}{Data file.}
  \item{varY}{Dependent variable.}
  \item{varX}{Quantitative independent variable.}
  \item{rylim}{Limits for the expanded plot of the Y axis.}
  \item{rxlim}{Limits for the expanded plot of the X axis.}
  \item{ResetPAR}{If it is FALSE, the default condition of the function \link[StatR]{PAR} is not placed and maintained those defined by the user in previous graphics.}
  \item{PAR}{It accesses the function \link[StatR]{PAR} that allows to modify many different aspects of the graph.}
  \item{XLAB}{Legends of the X axis.}
  \item{YLAB}{Legends of the Y axis.}
  \item{XLIM}{Limits of the X axis.}
  \item{YLIM}{Limits of the Y axis.}
  \item{MAIN}{Main title of the plot.}
  \item{titlepos}{Horizontal position of the main title.}
  \item{COLOR}{Color of the symbols.}
  \item{PCH}{Graphic symbol (see the description of the same argument in the function \link{F1}). It must be as many as the number of variables Y.}
  \item{ZOOM}{It accesses the function \link[plotrix]{zoomInPlot} that allows to modify many different aspects of the graph.}
  \item{MTEXT}{It allows to add text on the margins of the graph.}
  \item{TEXT}{It allows to add text in any area of the inner part of the graph.}
}
\value{It is depicted a scatterplot and a second graph with a zoom of the first graph.}  
\details{
\strong{FUNCTIONS}

The plot is performed with the function \link[plotrix]{zoomInPlot} of the package plotrix (Lemon et al., 2017). 

\strong{EXAMPLE}

For the examples, morphometric data of freshwater fishes, as the distance from the origin of the dorsal fin to the origin of the anal fin (M13), the length of the dorsal fin base (M12), body height (M11), etc., are used. For details see Guisande et al. (2010).

The next figure shows the relationship between the variables M11 and M13 and a zoom in an inner area.
\tabular{c}{
\figure{F194}{options: width=5in}
}
}
\references{
Lemon, J., Bolker, B., Oom, S., Klein, E., Rowlingson, B., Wickham, H., Tyagi, A., Eterradossi, O., Grothendieck, G., Toews, M., Kane, J., Turner, R., Witthoft, C., Stander, J., Petzoldt, T., Duursma, R., Biancotto, E., Levy, O., Dutang, C., Solymos, P., Engelmann, R., Hecker, M., Steinbeck, F., Borchers, H., Singmann, H., Toal, T. & Ogle, D. (2017) Various plotting functions. R package version 3.7. Available at: \url{https://CRAN.R-project.org/package=plotrix}.

Guisande, C., Manjarrs-Hernndez, A., Pelayo-Villamil, P., Granado-Lorencio, C., Riveiro, I., Acua, A., Prieto-Piraquive, E., Janeiro, E., Matas, J.M., Patti, C., Patti, B., Mazzola, S., Jimnez, S., Duque, V. & Salmern, F. (2010) IPez: An expert system for the taxonomic identification of fishes based on machine learning techniques. \emph{Fisheries Research}, 102, 240-247.
}
\examples{
\dontrun{

data(Z1)

F86(data = Z1 , varY = "M13" , varX="M11", rylim=c(0.35,0.4), rxlim=c(0.3,0.4),
MAIN="Morphometry characters of freshwater fishes", titlepos=0.26)}
}
\keyword{F86}
